@@ -1,7 +1,6 @@
 require 'Processor'
 require 'Aggregator'
 require "GeneratorCPP"
-require "GeneratorNET"
 require "GeneratorPython"
 require "GeneratorRuby"
 
@@ -23,10 +22,9 @@ def generateVersion( type, major, minor, sp, verid, aggregator )
   dir = "../src"
   xml = versionXML( type, major, minor, sp )
   cpp = GeneratorCPP.new(type, major.to_s, minor.to_s, sp.to_s, verid.to_s, "#{dir}/C++")
-  net = GeneratorNET.new(type, major.to_s, minor.to_s, sp.to_s, verid.to_s, "#{dir}/.NET")
   python = GeneratorPython.new(type, major.to_s, minor.to_s, sp.to_s, verid.to_s, "#{dir}/python")
   ruby = GeneratorRuby.new(type, major.to_s, minor.to_s, sp.to_s, verid.to_s, "#{dir}/ruby")
-  processor = Processor.new(xml, [cpp, net, python, ruby]).process( aggregator )
+  processor = Processor.new(xml, [cpp, python, ruby]).process( aggregator )
 end
 
 aggregator = Aggregator.new
@@ -36,4 +34,5 @@ aggregateFields( "FIXT", 1, 1, 0, aggregator )
 
 generateVersion( "FIXT", 1, 1, 0, 0, aggregator )
 (0..4).each { |i| generateVersion( "FIX", 4, i, 0, 0, aggregator ) }
-(0..2).each { |i| generateVersion( "FIX", 5, 0, i, i + 7, aggregator ) }
\ No newline at end of file
+(0..0).each { |i| generateVersion( "FIX", 4, i, 0, 0, aggregator ) }
+(0..2).each { |i| generateVersion( "FIX", 5, 0, i, i + 7, aggregator ) }
