@@ -33,6 +33,10 @@
 #include "FieldTypes.h"
 #include "Utility.h"
 
+#if defined(__SUNPRO_CC)
+#include <algorithm>
+#endif
+
 namespace FIX
 {
 /**
@@ -73,30 +77,62 @@ class FieldBase
   friend class Message;
 
   /// Constructor which also calculates field metrics
-  FieldBase( int field, 
+  FieldBase( int tag, 
              std::string::const_iterator valueStart, 
              std::string::const_iterator valueEnd,
              std::string::const_iterator tagStart, 
              std::string::const_iterator tagEnd )
-    : m_field( field )
+    : m_tag( tag )
     , m_string( valueStart, valueEnd )
     , m_metrics( calculateMetrics( tagStart, tagEnd ) )
   {}
 
 public:
-  FieldBase( int field, const std::string& string )
-    : m_field( field ), m_string(string), m_metrics( no_metrics() )
+  FieldBase( int tag, const std::string& string )
+    : m_tag( tag ), m_string(string), m_metrics( no_metrics() )
   {}
 
   virtual ~FieldBase() {}
 
-  void setField( int field )
+  FieldBase( const FieldBase& rhs )
+  : m_tag( rhs.getTag() )
+  , m_string( rhs.m_string )
+  , m_metrics( rhs.m_metrics )
   {
-    m_field = field;
+
+  }
+
+  FieldBase& operator=( const FieldBase& rhs)
+  {
+    m_tag = rhs.getTag();
+    m_string = rhs.m_string;
+    m_metrics = rhs.m_metrics;
+    m_data.clear();
+
+    return *this;
+  }
+
+  void swap( FieldBase& rhs )
+  {
+    std::swap( m_tag, rhs.m_tag );
+    std::swap( m_metrics, rhs.m_metrics );
+    m_string.swap( rhs.m_string );
+    m_data.swap( rhs.m_data );
+  }
+
+  void setTag( int tag )
+  {
+    m_tag = tag;
     m_metrics = no_metrics();
     m_data.clear();
   }
 
+  /// @deprecated Use setTag
+  void setField( int field )
+  {
+    setTag( field );
+  }
+
   void setString( const std::string& string )
   {
     m_string = string;
@@ -105,8 +141,12 @@ public:
   }
 
   /// Get the fields integer tag.
+  int getTag() const
+  { return m_tag; }
+
+  /// @deprecated Use getTag
   int getField() const
-  { return m_field; }
+  { return getTag(); }
 
   /// Get the string representation of the fields value.
   const std::string& getString() const
@@ -137,7 +177,7 @@ public:
 
   /// Compares fields based on their tag numbers
   bool operator < ( const FieldBase& field ) const
-  { return m_field < field.m_field; }
+  { return m_tag < field.m_tag; }
 
 private:
 
@@ -151,16 +191,16 @@ private:
   /// Serializes string representation of the Field to input string
   void encodeTo( std::string& result ) const
   {
-    size_t tagLength = FIX::number_of_symbols_in( m_field ) + 1;
-    size_t totalLength = tagLength + m_string.length() + 1;
+    size_t tagLength = FIX::number_of_symbols_in( m_tag );
+    size_t totalLength = tagLength + m_string.length() + 2;
 
     result.resize( totalLength );
 
     char * buf = (char*)result.c_str();
-    FIX::integer_to_string( buf, tagLength, m_field );
+    FIX::integer_to_string( buf, tagLength, m_tag );
 
-    buf[tagLength - 1] = '=';
-    memcpy( buf + tagLength, m_string.data(), m_string.length() );
+    buf[tagLength] = '=';
+    memcpy( buf + tagLength + 1, m_string.data(), m_string.length() );
     buf[totalLength - 1] = '\001';
   }
 
@@ -178,7 +218,13 @@ private:
     for ( std::string::const_iterator str = start; str != end; ++str )
       checksum += (unsigned char)( *str );
 
+#if defined(__SUNPRO_CC)
+    std::ptrdiff_t d;
+    std::distance(start, end, d);
+    return field_metrics( d, checksum );
+#else
     return field_metrics( std::distance( start, end ), checksum );
+#endif
   }
 
   static field_metrics calculateMetrics( const std::string& field )
@@ -186,7 +232,7 @@ private:
     return calculateMetrics( field.begin(), field.end() );
   }
 
-  int m_field;
+  int m_tag;
   std::string m_string;
   mutable std::string m_data;
   mutable field_metrics m_metrics;
@@ -200,6 +246,11 @@ inline std::ostream& operator <<
   return stream;
 }
 
+inline void swap( FieldBase& lhs, FieldBase& rhs )
+{
+  lhs.swap( rhs );
+}
+
 /**
  * MSC doesn't support partial template specialization so we have this.
  * this is here to provide equality checking against native char arrays.
@@ -323,7 +374,7 @@ public:
     { try
       { return CharConvertor::convert( getString() ); }
       catch( FieldConvertError& )
-      { throw IncorrectDataFormat( getField(), getString() ); } }
+      { throw IncorrectDataFormat( getTag(), getString() ); } }
   operator char() const
     { return getValue(); }
 };
@@ -343,7 +394,7 @@ public:
     { try
       { return DoubleConvertor::convert( getString() ); }
       catch( FieldConvertError& )
-      { throw IncorrectDataFormat( getField(), getString() ); } }
+      { throw IncorrectDataFormat( getTag(), getString() ); } }
   operator double() const
     { return getValue(); }
 };
@@ -363,7 +414,7 @@ public:
     { try
       { return IntConvertor::convert( getString() ); }
       catch( FieldConvertError& )
-      { throw IncorrectDataFormat( getField(), getString() ); } }
+      { throw IncorrectDataFormat( getTag(), getString() ); } }
   operator const int() const
     { return getValue(); }
 };
@@ -383,7 +434,7 @@ public:
     { try
       { return BoolConvertor::convert( getString() ); }
       catch( FieldConvertError& )
-      { throw IncorrectDataFormat( getField(), getString() ); } }
+      { throw IncorrectDataFormat( getTag(), getString() ); } }
   operator bool() const
     { return getValue(); }
 };
@@ -392,10 +443,10 @@ public:
 class UtcTimeStampField : public FieldBase
 {
 public:
-  explicit UtcTimeStampField( int field, const UtcTimeStamp& data, bool showMilliseconds = false )
-: FieldBase( field, UtcTimeStampConvertor::convert( data, showMilliseconds ) ) {}
-  UtcTimeStampField( int field, bool showMilliseconds = false )
-: FieldBase( field, UtcTimeStampConvertor::convert( UtcTimeStamp(), showMilliseconds ) ) {}
+  explicit UtcTimeStampField( int field, const UtcTimeStamp& data, int precision = 0 )
+: FieldBase( field, UtcTimeStampConvertor::convert( data, precision ) ) {}
+  UtcTimeStampField( int field, int precision = 0 )
+: FieldBase( field, UtcTimeStampConvertor::convert( UtcTimeStamp(), precision ) ) {}
 
   void setValue( const UtcTimeStamp& value )
     { setString( UtcTimeStampConvertor::convert( value ) ); }
@@ -403,7 +454,7 @@ public:
     { try
       { return UtcTimeStampConvertor::convert( getString() ); }
       catch( FieldConvertError& )
-      { throw IncorrectDataFormat( getField(), getString() ); } }
+      { throw IncorrectDataFormat( getTag(), getString() ); } }
   operator UtcTimeStamp() const
     { return getValue(); }
 
@@ -430,7 +481,7 @@ public:
     { try
       { return UtcDateConvertor::convert( getString() ); }
       catch( FieldConvertError& )
-      { throw IncorrectDataFormat( getField(), getString() ); } }
+      { throw IncorrectDataFormat( getTag(), getString() ); } }
   operator UtcDate() const
     { return getValue(); }
 
@@ -446,10 +497,10 @@ public:
 class UtcTimeOnlyField : public FieldBase
 {
 public:
-  explicit UtcTimeOnlyField( int field, const UtcTimeOnly& data, bool showMilliseconds = false )
-: FieldBase( field, UtcTimeOnlyConvertor::convert( data, showMilliseconds ) ) {}
-  UtcTimeOnlyField( int field, bool showMilliseconds = false )
-: FieldBase( field, UtcTimeOnlyConvertor::convert( UtcTimeOnly(), showMilliseconds ) ) {}
+  explicit UtcTimeOnlyField( int field, const UtcTimeOnly& data, int precision = 0 )
+: FieldBase( field, UtcTimeOnlyConvertor::convert( data, precision ) ) {}
+  UtcTimeOnlyField( int field, int precision = 0 )
+: FieldBase( field, UtcTimeOnlyConvertor::convert( UtcTimeOnly(), precision ) ) {}
 
   void setValue( const UtcTimeOnly& value )
     { setString( UtcTimeOnlyConvertor::convert( value ) ); }
@@ -457,7 +508,7 @@ public:
     { try
       { return UtcTimeOnlyConvertor::convert( getString() ); }
       catch( FieldConvertError& )
-      { throw IncorrectDataFormat( getField(), getString() ); } }
+      { throw IncorrectDataFormat( getTag(), getString() ); } }
   operator UtcTimeOnly() const
     { return getValue(); }
 
@@ -484,7 +535,7 @@ public:
     { try
       { return CheckSumConvertor::convert( getString() ); }
       catch( FieldConvertError& )
-      { throw IncorrectDataFormat( getField(), getString() ); } }
+      { throw IncorrectDataFormat( getTag(), getString() ); } }
   operator const int() const
     { return getValue(); }
 };
@@ -529,9 +580,9 @@ DEFINE_FIELD_CLASS_NUM(NAME, TOK, TYPE, DEPRECATED_FIELD::NAME)
 #define DEFINE_FIELD_TIMECLASS_NUM( NAME, TOK, TYPE, NUM ) \
 class NAME : public TOK##Field { public: \
 NAME() : TOK##Field(NUM, false) {} \
-NAME(bool showMilliseconds) : TOK##Field(NUM, showMilliseconds) {} \
+NAME(int precision) : TOK##Field(NUM, precision) {} \
 NAME(const TYPE& value) : TOK##Field(NUM, value) {} \
-NAME(const TYPE& value, bool showMilliseconds) : TOK##Field(NUM, value, showMilliseconds) {} \
+NAME(const TYPE& value, int precision) : TOK##Field(NUM, value, precision) {} \
 }
 
 #define DEFINE_FIELD_TIMECLASS( NAME, TOK, TYPE ) \
