@@ -33,14 +33,14 @@ namespace FIX {
 
 DateTime DateTime::nowUtc()
 {
-#if defined( HAVE_FTIME )
+#if defined( _POSIX_SOURCE ) || defined(HAVE_GETTIMEOFDAY)
+    struct timeval tv;
+    gettimeofday (&tv, 0);
+    return fromUtcTimeT( tv.tv_sec, tv.tv_usec, 6 );
+#elif defined( HAVE_FTIME )
     timeb tb;
     ftime (&tb);
     return fromUtcTimeT (tb.time, tb.millitm);
-#elif defined( _POSIX_SOURCE )
-    struct timeval tv;
-    gettimeofday (&tv, 0);
-    return fromUtcTimeT( tv.tv_sec, tv.tv_usec / 1000 );
 #else
     return fromUtcTimeT( ::time (0), 0 );
 #endif
@@ -48,14 +48,14 @@ DateTime DateTime::nowUtc()
 
 DateTime DateTime::nowLocal()
 {
-#if defined( HAVE_FTIME )
+#if defined( _POSIX_SOURCE ) || defined(HAVE_GETTIMEOFDAY)
+    struct timeval tv;
+    gettimeofday (&tv, 0);
+    return fromLocalTimeT( tv.tv_sec, tv.tv_usec, 6 );
+#elif defined( HAVE_FTIME )
     timeb tb;
     ftime (&tb);
     return fromLocalTimeT( tb.time, tb.millitm );
-#elif defined( _POSIX_SOURCE )
-    struct timeval tv;
-    gettimeofday (&tv, 0);
-    return fromLocalTimeT( tv.tv_sec, tv.tv_usec / 1000 );
 #else
     return fromLocalTimeT( ::time (0), 0 );
 #endif
