@@ -1,5 +1,5 @@
 /****************************************************************************
-** Copyright (c) quickfixengine.org  All rights reserved.
+** Copyright (c) 2001-2014
 **
 ** This file is part of the QuickFIX FIX Engine
 **
@@ -22,7 +22,6 @@
 #else
 #include "config.h"
 #endif
-#include "CallStack.h"
 
 #include "HttpParser.h"
 #include "Utility.h"
@@ -32,8 +31,7 @@ namespace FIX
 {
 bool HttpParser::readHttpMessage( std::string& str )
 throw( MessageParseError )
-{ QF_STACK_PUSH(HttpParser::readFixMessage)
-
+{
   std::string::size_type pos = 0;
 
   if( m_buffer.length() < 4 ) 
@@ -43,11 +41,9 @@ throw( MessageParseError )
     throw MessageParseError();
   if( pos == std::string::npos ) 
     return false;
-  str = m_buffer.substr( 0, pos + 4 );
+  str.assign( m_buffer, 0, pos + 4 );
   m_buffer.erase( 0, pos + 4 );
 
   return true;
-
-  QF_STACK_POP
 }
 }
