@@ -37,25 +37,75 @@
 
 namespace FIX
 {
-static int const headerOrder[] =
-  {
-    FIELD::BeginString,
-    FIELD::BodyLength,
-    FIELD::MsgType
-  };
 
-class Header : public FieldMap 
+class Header : public FieldMap
 {
+  enum { REQUIRED_FIELDS = 8 };
+
 public:
-  Header() : FieldMap(message_order( message_order::header ) )
+  Header() : FieldMap( message_order( message_order::header ), REQUIRED_FIELDS )
   {}
+
+  Header(const message_order & order) : FieldMap(order)
+  {}
+
+  void addGroup( const FIX::Group& group )
+  { FieldMap::addGroup( group.field(), group ); }
+
+  void replaceGroup( unsigned num, const FIX::Group& group )
+  { FieldMap::replaceGroup( num, group.field(), group ); }
+
+  Group& getGroup( unsigned num, FIX::Group& group ) const throw( FieldNotFound )
+  { group.clear();
+    return static_cast < Group& >
+      ( FieldMap::getGroup( num, group.field(), group ) );
+  }
+
+  void removeGroup( unsigned num, const FIX::Group& group )
+  { FieldMap::removeGroup( num, group.field() ); }
+  void removeGroup( const FIX::Group& group )
+  { FieldMap::removeGroup( group.field() ); }
+
+  bool hasGroup( const FIX::Group& group ) const
+  { return FieldMap::hasGroup( group.field() ); }
+  bool hasGroup( unsigned num, const FIX::Group& group ) const
+  { return FieldMap::hasGroup( num, group.field() ); }
+
 };
 
-class Trailer : public FieldMap 
+class Trailer : public FieldMap
 {
+  enum { REQUIRED_FIELDS = 1 };
+
 public:
-  Trailer() : FieldMap(message_order( message_order::trailer ) )
+  Trailer() : FieldMap( message_order( message_order::trailer ), REQUIRED_FIELDS )
   {}
+
+  Trailer(const message_order & order) : FieldMap(order)
+  {}
+
+  void addGroup( const FIX::Group& group )
+  { FieldMap::addGroup( group.field(), group ); }
+
+  void replaceGroup( unsigned num, const FIX::Group& group )
+  { FieldMap::replaceGroup( num, group.field(), group ); }
+
+  Group& getGroup( unsigned num, FIX::Group& group ) const throw( FieldNotFound )
+  { group.clear();
+    return static_cast < Group& >
+      ( FieldMap::getGroup( num, group.field(), group ) );
+  }
+
+  void removeGroup( unsigned num, const FIX::Group& group )
+  { FieldMap::removeGroup( num, group.field() ); }
+  void removeGroup( const FIX::Group& group )
+  { FieldMap::removeGroup( group.field() ); }
+
+  bool hasGroup( const FIX::Group& group ) const
+  { return FieldMap::hasGroup( group.field() ); }
+  bool hasGroup( unsigned num, const FIX::Group& group ) const
+  { return FieldMap::hasGroup( num, group.field() ); }
+
 };
 
 /**
@@ -74,6 +124,9 @@ class Message : public FieldMap
 public:
   Message();
 
+  /// Construct message with a specified order of fields
+  Message( const message_order& hdrOrder, const message_order& trlOrder,  const message_order& order);
+
   /// Construct a message from a string
   Message( const std::string& string, bool validate = true )
   throw( InvalidMessage );
@@ -88,14 +141,19 @@ public:
            const FIX::DataDictionary& applicationDataDictionary, bool validate = true )
   throw( InvalidMessage );
 
-  Message( const Message& copy )
-  : FieldMap( copy )
-  {
-    m_header = copy.m_header;
-    m_trailer = copy.m_trailer;
-    m_validStructure = copy.m_validStructure;
-    m_field = copy.m_field;
-  }
+  /// Construct a message from a string using a data dictionary
+  Message( const message_order& hdrOrder, const message_order& trlOrder,  const message_order& order, const std::string& string, const FIX::DataDictionary& dataDictionary,
+           bool validate = true )
+  throw( InvalidMessage );
+
+  /// Construct a message from a string using a session and application data dictionary
+  Message( const message_order& hdrOrder, const message_order& trlOrder,  const message_order& order, const std::string& string, const FIX::DataDictionary& sessionDataDictionary,
+           const FIX::DataDictionary& applicationDataDictionary, bool validate = true )
+  throw( InvalidMessage );
+
+  Message( const Message& copy );
+
+  ~Message();
 
   /// Set global data dictionary for encoding messages into XML
   static bool InitializeXML( const std::string& string );
@@ -124,12 +182,7 @@ public:
 
 protected:
   // Constructor for derived classes
-  Message( const BeginString& beginString, const MsgType& msgType )
-  : m_validStructure( true )
-  {
-    m_header.setField( beginString );
-    m_header.setField( msgType );
-  }
+  Message( const BeginString& beginString, const MsgType& msgType );
 
 public:
   /// Get a string representation of the message
@@ -139,7 +192,7 @@ public:
   /// Get a string representation without making a copy
   std::string& toString( std::string&,
                          int beginStringField = FIELD::BeginString,
-                         int bodyLengthField = FIELD::BodyLength, 
+                         int bodyLengthField = FIELD::BodyLength,
                          int checkSumField = FIELD::CheckSum ) const;
   /// Get a XML representation of the message
   std::string toXML() const;
@@ -197,13 +250,13 @@ public:
   /// Mutable getter for the message trailer
   Trailer& getTrailer() { return m_trailer; }
 
-  bool hasValidStructure(int& field) const
-  { field = m_field;
+  bool hasValidStructure(int& tag) const
+  { tag = m_tag;
     return m_validStructure;
   }
 
-  int bodyLength( int beginStringField = FIELD::BeginString, 
-                  int bodyLengthField = FIELD::BodyLength, 
+  int bodyLength( int beginStringField = FIELD::BeginString,
+                  int bodyLengthField = FIELD::BodyLength,
                   int checkSumField = FIELD::CheckSum ) const
   { return m_header.calculateLength(beginStringField, bodyLengthField, checkSumField)
            + calculateLength(beginStringField, bodyLengthField, checkSumField)
@@ -218,21 +271,17 @@ public:
 
   bool isAdmin() const
   { 
-    if( m_header.isSetField(FIELD::MsgType) )
-    {
-      const MsgType& msgType = FIELD_GET_REF( m_header, MsgType );
+    MsgType msgType;
+    if( m_header.getFieldIfSet( msgType ) )
       return isAdminMsgType( msgType );
-    }
     return false;
   }
 
   bool isApp() const
   { 
-    if( m_header.isSetField(FIELD::MsgType) )
-    {
-      const MsgType& msgType = FIELD_GET_REF( m_header, MsgType );
+    MsgType msgType;
+    if( m_header.getFieldIfSet( msgType ) )
       return !isAdminMsgType( msgType );
-    }
     return false;
   }
 
@@ -240,8 +289,9 @@ public:
   { return m_header.isEmpty() && FieldMap::isEmpty() && m_trailer.isEmpty(); }
 
   void clear()
-  { 
-    m_field = 0;
+  {
+    m_tag = 0;
+    m_validStructure = true;
     m_header.clear();
     FieldMap::clear();
     m_trailer.clear();
@@ -300,10 +350,14 @@ public:
   static bool isHeaderField( int field );
   static bool isHeaderField( const FieldBase& field,
                              const DataDictionary* pD = 0 );
+  static bool isHeaderField( int field,
+                             const DataDictionary* pD );
 
   static bool isTrailerField( int field );
   static bool isTrailerField( const FieldBase& field,
                               const DataDictionary* pD = 0 );
+  static bool isTrailerField( int field,
+                              const DataDictionary* pD );
 
   /// Returns the session ID of the intended recipient
   SessionID getSessionID( const std::string& qualifier = "" ) const
@@ -311,15 +365,20 @@ public:
   /// Sets the session ID of the intended recipient
   void setSessionID( const SessionID& sessionID );
 
+#ifdef HAVE_EMX
+  void  setSubMessageType(const std::string & subMsgType) { m_subMsgType.assign(subMsgType); }
+  const std::string & getSubMessageType() const { return m_subMsgType; }
+#endif
+
 private:
-  FieldBase extractField( 
+  FieldBase extractField(
     const std::string& string, std::string::size_type& pos,
     const DataDictionary* pSessionDD = 0, const DataDictionary* pAppDD = 0,
-    const Group* pGroup = 0);
+    const Group* pGroup = 0) const;
 
-  static bool IsDataField( 
-    int field, 
-    const DataDictionary* pSessionDD, 
+  static bool IsDataField(
+    int field,
+    const DataDictionary* pSessionDD,
     const DataDictionary* pAppDD )
   {
     if( (pSessionDD && pSessionDD->isDataField( field )) ||
@@ -331,15 +390,18 @@ private:
     return false;
   }
 
-  void validate();
+  void validate() const;
   std::string toXMLFields(const FieldMap& fields, int space) const;
 
 protected:
   mutable Header m_header;
   mutable Trailer m_trailer;
   bool m_validStructure;
-  int m_field;
-  static std::auto_ptr<DataDictionary> s_dataDictionary;
+  int m_tag;
+#ifdef HAVE_EMX
+  std::string m_subMsgType;
+#endif
+  static SmartPtr<DataDictionary> s_dataDictionary;
 };
 /*! @} */
 
