@@ -180,9 +180,22 @@ public:
     { m_refreshOnLogon = value; } 
 
   bool getMillisecondsInTimeStamp()
-    { return m_millisecondsInTimeStamp; }
+    { return (m_timestampPrecision == 3); }
   void setMillisecondsInTimeStamp ( bool value )
-    { m_millisecondsInTimeStamp = value; }
+    { if (value)
+        m_timestampPrecision = 3;
+      else
+        m_timestampPrecision = 0;
+    }
+  int getTimestampPrecision()
+    { return m_timestampPrecision; }
+  void setTimestampPrecision(int precision)
+    {
+      if (precision < 0 || precision > 9)
+        return;
+
+      m_timestampPrecision = precision;
+    }
 
   bool getPersistMessages()
     { return m_persistMessages; }
@@ -298,6 +311,8 @@ private:
   bool set( int s, const Message& m );
   bool get( int s, Message& m ) const;
 
+  Message * newMessage(const std::string & msgType) const;
+
   Application& m_application;
   SessionID m_sessionID;
   TimeRange m_sessionTime;
@@ -313,7 +328,7 @@ private:
   bool m_resetOnLogout;
   bool m_resetOnDisconnect;
   bool m_refreshOnLogon;
-  bool m_millisecondsInTimeStamp;
+  int m_timestampPrecision;
   bool m_persistMessages;
   bool m_validateLengthAndChecksum;
 
@@ -328,7 +343,6 @@ private:
   static SessionIDs s_sessionIDs;
   static Sessions s_registered;
   static Mutex s_mutex;
-
 };
 }
 
