@@ -63,14 +63,18 @@ const char SOCKET_ACCEPT_PORT[] = "SocketAcceptPort";
 const char SOCKET_REUSE_ADDRESS[] = "SocketReuseAddress";
 const char SOCKET_CONNECT_HOST[] = "SocketConnectHost";
 const char SOCKET_CONNECT_PORT[] = "SocketConnectPort";
+const char SOCKET_CONNECT_SOURCE_HOST[] = "SocketConnectSourceHost";
+const char SOCKET_CONNECT_SOURCE_PORT[] = "SocketConnectSourcePort";
 const char SOCKET_NODELAY[] = "SocketNodelay";
-const char SOCKET_SEND_BUFFER_SIZE[] = "SendBufferSize";
-const char SOCKET_RECEIVE_BUFFER_SIZE[] = "ReceiveBufferSize";
+const char SOCKET_SEND_BUFFER_SIZE[] = "SocketSendBufferSize";
+const char SOCKET_RECEIVE_BUFFER_SIZE[] = "SocketReceiveBufferSize";
 const char RECONNECT_INTERVAL[] = "ReconnectInterval";
 const char VALIDATE_LENGTH_AND_CHECKSUM[] = "ValidateLengthAndChecksum";
 const char VALIDATE_FIELDS_OUT_OF_ORDER[] = "ValidateFieldsOutOfOrder";
 const char VALIDATE_FIELDS_HAVE_VALUES[] = "ValidateFieldsHaveValues";
 const char VALIDATE_USER_DEFINED_FIELDS[] = "ValidateUserDefinedFields";
+const char ALLOW_UNKNOWN_MSG_FIELDS[] = "AllowUnknownMsgFields";
+const char PRESERVE_MESSAGE_FIELDS_ORDER[] = "PreserveMessageFieldsOrder";
 const char LOGON_TIMEOUT[] = "LogonTimeout";
 const char LOGOUT_TIMEOUT[] = "LogoutTimeout";
 const char FILE_STORE_PATH[] = "FileStorePath";
@@ -123,16 +127,102 @@ const char RESET_ON_LOGOUT[] = "ResetOnLogout";
 const char RESET_ON_DISCONNECT[] = "ResetOnDisconnect";
 const char REFRESH_ON_LOGON[] = "RefreshOnLogon";
 const char MILLISECONDS_IN_TIMESTAMP[] = "MillisecondsInTimeStamp";
+const char TIMESTAMP_PRECISION[] = "TimestampPrecision";
 const char HTTP_ACCEPT_PORT[] = "HttpAcceptPort";
 const char PERSIST_MESSAGES[] = "PersistMessages";
+const char SERVER_CERT_FILE[] = "ServerCertificateFile";
+const char SERVER_CERT_KEY_FILE[] = "ServerCertificateKeyFile";
+const char CLIENT_CERT_FILE[] = "ClientCertificateFile";
+const char CLIENT_CERT_KEY_FILE[] = "ClientCertificateKeyFile";
+const char CERT_AUTH_FILE[] = "CertificationAuthoritiesFile";
+const char CERT_AUTH_DIR[] = "CertificationAuthoritiesDirectory";
+const char CRL_FILE[] = "CertificateRevocationListFile";
+const char CRL_DIR[] = "CertificateRevocationListDirectory";
+const char VERIFY_LEVEL[] = "CertificateVerifyLevel";
+/*
+# This directive can be used to control the SSL protocol flavors the application
+# should use when establishing its environment.
+#
+# The available (case-insensitive) protocols are:
+#
+# SSLv2
+#
+#  This is the Secure Sockets Layer (SSL) protocol, version 2.0. It is the
+#  original SSL protocol as designed by Netscape Corporation.
+#
+# SSLv3
+#
+#  This is the Secure Sockets Layer (SSL) protocol, version 3.0. It is the
+#  successor to SSLv2 and the currently (as of February 1999) de-facto
+#  standardized SSL protocol from Netscape Corporation. It's supported by
+#  almost all popular browsers.
+#
+# TLSv1
+#
+#  This is the Transport Layer Security (TLS) protocol, version 1.0.
+#
+# TLSv1_1
+#
+#  This is the Transport Layer Security (TLS) protocol, version 1.1.
+#
+# TLSv1_2
+#
+#  This is the Transport Layer Security (TLS) protocol, version 1.2.
+#
+# all
+#
+#  This is a shortcut for `+SSLv2 +SSLv3 +TLSv1 +TLSv1_1 +TLSv1_2' and a convenient way for
+#  enabling all protocols except one when used in combination with the minus
+#  sign on a protocol as the example above shows.
+#
+# Example:
+#
+#  enable all but not SSLv2
+#  SSL_PROTOCOL = all -SSLv2
+#
+# `all -SSLv2` is the default value when the parameter is not specified.
+
+*/
+const char SSL_PROTOCOL[] = "SSLProtocol";
+/*
+# This complex directive uses a colon-separated cipher-spec string consisting
+# of OpenSSL cipher specifications to configure the Cipher Suite the client is
+# permitted to negotiate in the SSL handshake phase. Notice that this directive
+# can be used both in per-server and per-directory context. In per-server
+# context it applies to the standard SSL handshake when a connection is
+# established. In per-directory context it forces a SSL renegotation with the
+# reconfigured Cipher Suite after the HTTP request was read but before the HTTP
+# response is sent.
+#
+# An SSL cipher specification in cipher-spec is composed of 4 major attributes
+# plus a few extra minor ones:
+#
+# Key Exchange Algorithm:
+#  RSA or Diffie-Hellman variants.
+#
+# Authentication Algorithm:
+#  RSA, Diffie-Hellman, DSS or none.
+#
+# Cipher/Encryption Algorithm:
+#  DES, Triple-DES, RC4, RC2, IDEA or none.
+#
+# MAC Digest Algorithm:
+#  MD5, SHA or SHA1.
+#
+# For more details refer to mod_ssl documentation.
+#
+# Example: RC4+RSA:+HIGH:
+*/
+const char SSL_CIPHER_SUITE[] = "SSLCipherSuite";
+
 
 /// Container for setting dictionaries mapped to sessions.
 class SessionSettings
 {
 public:
-  SessionSettings() {}
-  SessionSettings( std::istream& stream ) throw( ConfigError );
-  SessionSettings( const std::string& file ) throw( ConfigError );
+  SessionSettings() { m_resolveEnvVars = false; }
+  SessionSettings( std::istream& stream, bool resolveEnvVars = false ) throw( ConfigError );
+  SessionSettings( const std::string& file, bool resolveEnvVars = false ) throw( ConfigError );
 
   /// Check if session setings are present
   const bool has( const SessionID& ) const;
@@ -158,7 +248,9 @@ private:
 
   Dictionaries m_settings;
   Dictionary m_defaults;
+  bool m_resolveEnvVars;  // while reading, replace $var, $(var) and ${var} by environment variable var
 
+  friend std::istream& operator>>( std::istream&, SessionSettings& ) throw( ConfigError );
   friend std::ostream& operator<<( std::ostream&, const SessionSettings& );
 };
 /*! @} */
