@@ -83,7 +83,8 @@ SocketConnector::SocketConnector( int timeout )
 : m_monitor( timeout ) {}
 
 int SocketConnector::connect( const std::string& address, int port, bool noDelay,
-                              int sendBufSize, int rcvBufSize )
+                              int sendBufSize, int rcvBufSize,
+                              const std::string& sourceAddress, int sourcePort)
 {
   int socket = socket_createConnector();
 
@@ -95,6 +96,8 @@ int SocketConnector::connect( const std::string& address, int port, bool noDelay
       socket_setsockopt( socket, SO_SNDBUF, sendBufSize );
     if( rcvBufSize )
       socket_setsockopt( socket, SO_RCVBUF, rcvBufSize );
+    if ( !sourceAddress.empty() || sourcePort )
+          socket_bind( socket, sourceAddress.c_str(), sourcePort );
     m_monitor.addConnect( socket );
     socket_connect( socket, address.c_str(), port );
   }
@@ -104,7 +107,7 @@ int SocketConnector::connect( const std::string& address, int port, bool noDelay
 int SocketConnector::connect( const std::string& address, int port, bool noDelay, 
                               int sendBufSize, int rcvBufSize, Strategy& strategy )
 {
-  int socket = connect( address, port, noDelay, sendBufSize, rcvBufSize );
+  int socket = connect( address, port, noDelay, sendBufSize, rcvBufSize, "", 0);
   return socket;
 }
 
