@@ -134,15 +134,18 @@ void SocketInitiator::doConnect( const SessionID& s, const Dictionary& d )
   {
     std::string address;
     short port = 0;
+    std::string sourceAddress;
+    short sourcePort = 0;
+
     Session* session = Session::lookupSession( s );
     if( !session->isSessionTime(UtcTimeStamp()) ) return;
 
     Log* log = session->getLog();
 
-    getHost( s, d, address, port );
+    getHost( s, d, address, port, sourceAddress, sourcePort );
 
-    log->onEvent( "Connecting to " + address + " on port " + IntConvertor::convert((unsigned short)port) );
-    int result = m_connector.connect( address, port, m_noDelay, m_sendBufSize, m_rcvBufSize );
+    log->onEvent( "Connecting to " + address + " on port " + IntConvertor::convert((unsigned short)port) + " (Source " + sourceAddress + ":" + IntConvertor::convert((unsigned short)sourcePort) + ")");
+    int result = m_connector.connect( address, port, m_noDelay, m_sendBufSize, m_rcvBufSize, sourceAddress, sourcePort );
     setPending( s );
 
     m_pendingConnections[ result ] 
@@ -229,7 +232,8 @@ void SocketInitiator::onTimeout( SocketConnector& )
 }
 
 void SocketInitiator::getHost( const SessionID& s, const Dictionary& d,
-                               std::string& address, short& port )
+                               std::string& address, short& port,
+                               std::string& sourceAddress, short& sourcePort)
 {
   int num = 0;
   SessionToHostNum::iterator i = m_sessionToHostNum.find( s );
@@ -243,16 +247,36 @@ void SocketInitiator::getHost( const SessionID& s, const Dictionary& d,
   portStream << SOCKET_CONNECT_PORT << num;
   std::string portString = portStream.str();
 
+  sourcePort = 0;
+  sourceAddress.empty();
+
   if( d.has(hostString) && d.has(portString) )
   {
     address = d.getString( hostString );
     port = ( short ) d.getInt( portString );
+
+    std::stringstream sourceHostStream;
+    sourceHostStream << SOCKET_CONNECT_SOURCE_HOST << num;
+    hostString = sourceHostStream.str();
+    if( d.has(hostString) )
+      sourceAddress = d.getString( hostString );
+
+    std::stringstream sourcePortStream;
+    sourcePortStream << SOCKET_CONNECT_SOURCE_PORT << num;
+    portString = sourcePortStream.str();
+    if( d.has(portString) )
+      sourcePort = ( short ) d.getInt( portString );
   }
   else
   {
     num = 0;
     address = d.getString( SOCKET_CONNECT_HOST );
     port = ( short ) d.getInt( SOCKET_CONNECT_PORT );
+
+    if( d.has(SOCKET_CONNECT_SOURCE_HOST) )
+      sourceAddress = d.getString( SOCKET_CONNECT_SOURCE_HOST );
+    if( d.has(SOCKET_CONNECT_SOURCE_PORT) )
+      sourcePort = ( short ) d.getInt( SOCKET_CONNECT_SOURCE_PORT );
   }
 
   m_sessionToHostNum[ s ] = ++num;
