@@ -100,6 +100,23 @@ void socket_term()
 #endif
 }
 
+int socket_bind( int socket, const char* hostname, int port )
+{
+  sockaddr_in address;
+  socklen_t socklen;
+
+  address.sin_family = PF_INET;
+  address.sin_port = htons( port );
+  if ( !hostname || !*hostname )
+    address.sin_addr.s_addr = INADDR_ANY;
+  else
+    address.sin_addr.s_addr = inet_addr( hostname );
+  socklen = sizeof( address );
+
+  return  bind( socket, reinterpret_cast < sockaddr* > ( &address ),
+                     socklen );
+}
+
 int socket_createAcceptor(int port, bool reuse)
 {
   int socket = ::socket( PF_INET, SOCK_STREAM, 0 );
@@ -150,6 +167,11 @@ int socket_accept( int s )
   return accept( s, 0, 0 );
 }
 
+ssize_t socket_recv( int s, char* buf, size_t length )
+{
+  return recv( s, buf, length, 0 );
+}
+
 ssize_t socket_send( int s, const char* msg, size_t length )
 {
   return send( s, msg, length, 0 );
@@ -396,7 +418,7 @@ bool thread_spawn( THREAD_START_ROUTINE func, void* var, thread_id& thread )
 #ifdef _MSC_VER
   thread_id result = 0;
   unsigned int id = 0;
-  result = _beginthreadex( NULL, 0, &func, var, 0, &id );
+  result = _beginthreadex( NULL, 0, func, var, 0, &id );
   if ( result == 0 ) return false;
 #else
   thread_id result = 0;
