@@ -1,7 +1,7 @@
 /* -*- C++ -*- */
  
 /****************************************************************************
-** Copyright (c) quickfixengine.org  All rights reserved.
+** Copyright (c) 2001-2014
 **
 ** This file is part of the QuickFIX FIX Engine
 **
@@ -22,8 +22,10 @@
 #ifndef FIX42_MESSAGECRACKER_H
 #define FIX42_MESSAGECRACKER_H
 
+
 #include "../SessionID.h"
 #include "../Exceptions.h"
+
 #include "../fix42/Message.h"
 
 namespace FIX42
@@ -34,7 +36,7 @@ namespace FIX42
   class Reject; 
   class SequenceReset; 
   class Logout; 
-  class IndicationofInterest; 
+  class IOI; 
   class Advertisement; 
   class ExecutionReport; 
   class OrderCancelReject; 
@@ -51,7 +53,7 @@ namespace FIX42
   class ListExecute; 
   class ListStatusRequest; 
   class ListStatus; 
-  class AllocationACK; 
+  class AllocationInstructionAck; 
   class DontKnowTrade; 
   class QuoteRequest; 
   class Quote; 
@@ -95,7 +97,7 @@ namespace FIX42
     {}
   virtual void onMessage( const Logout&, const FIX::SessionID& ) 
     {}
-  virtual void onMessage( const IndicationofInterest&, const FIX::SessionID& ) 
+  virtual void onMessage( const IOI&, const FIX::SessionID& ) 
     { throw FIX::UnsupportedMessageType(); }
   virtual void onMessage( const Advertisement&, const FIX::SessionID& ) 
     { throw FIX::UnsupportedMessageType(); }
@@ -129,7 +131,7 @@ namespace FIX42
     { throw FIX::UnsupportedMessageType(); }
   virtual void onMessage( const ListStatus&, const FIX::SessionID& ) 
     { throw FIX::UnsupportedMessageType(); }
-  virtual void onMessage( const AllocationACK&, const FIX::SessionID& ) 
+  virtual void onMessage( const AllocationInstructionAck&, const FIX::SessionID& ) 
     { throw FIX::UnsupportedMessageType(); }
   virtual void onMessage( const DontKnowTrade&, const FIX::SessionID& ) 
     { throw FIX::UnsupportedMessageType(); }
@@ -181,7 +183,7 @@ namespace FIX42
  virtual void onMessage( Reject&, const FIX::SessionID& ) {} 
  virtual void onMessage( SequenceReset&, const FIX::SessionID& ) {} 
  virtual void onMessage( Logout&, const FIX::SessionID& ) {} 
- virtual void onMessage( IndicationofInterest&, const FIX::SessionID& ) {} 
+ virtual void onMessage( IOI&, const FIX::SessionID& ) {} 
  virtual void onMessage( Advertisement&, const FIX::SessionID& ) {} 
  virtual void onMessage( ExecutionReport&, const FIX::SessionID& ) {} 
  virtual void onMessage( OrderCancelReject&, const FIX::SessionID& ) {} 
@@ -198,7 +200,7 @@ namespace FIX42
  virtual void onMessage( ListExecute&, const FIX::SessionID& ) {} 
  virtual void onMessage( ListStatusRequest&, const FIX::SessionID& ) {} 
  virtual void onMessage( ListStatus&, const FIX::SessionID& ) {} 
- virtual void onMessage( AllocationACK&, const FIX::SessionID& ) {} 
+ virtual void onMessage( AllocationInstructionAck&, const FIX::SessionID& ) {} 
  virtual void onMessage( DontKnowTrade&, const FIX::SessionID& ) {} 
  virtual void onMessage( QuoteRequest&, const FIX::SessionID& ) {} 
  virtual void onMessage( Quote&, const FIX::SessionID& ) {} 
@@ -248,7 +250,7 @@ public:
       onMessage( (const Logout&)message, sessionID );
     else
     if( msgTypeValue == "6" )
-      onMessage( (const IndicationofInterest&)message, sessionID );
+      onMessage( (const IOI&)message, sessionID );
     else
     if( msgTypeValue == "7" )
       onMessage( (const Advertisement&)message, sessionID );
@@ -299,7 +301,7 @@ public:
       onMessage( (const ListStatus&)message, sessionID );
     else
     if( msgTypeValue == "P" )
-      onMessage( (const AllocationACK&)message, sessionID );
+      onMessage( (const AllocationInstructionAck&)message, sessionID );
     else
     if( msgTypeValue == "Q" )
       onMessage( (const DontKnowTrade&)message, sessionID );
@@ -395,7 +397,7 @@ void crack( Message& message,
       onMessage( (Logout&)message, sessionID );
     else
     if( msgTypeValue == "6" )
-      onMessage( (IndicationofInterest&)message, sessionID );
+      onMessage( (IOI&)message, sessionID );
     else
     if( msgTypeValue == "7" )
       onMessage( (Advertisement&)message, sessionID );
@@ -446,7 +448,7 @@ void crack( Message& message,
       onMessage( (ListStatus&)message, sessionID );
     else
     if( msgTypeValue == "P" )
-      onMessage( (AllocationACK&)message, sessionID );
+      onMessage( (AllocationInstructionAck&)message, sessionID );
     else
     if( msgTypeValue == "Q" )
       onMessage( (DontKnowTrade&)message, sessionID );
@@ -519,4 +521,4 @@ void crack( Message& message,
   };
 }
 
-#endif //FIX42_MESSAGECRACKER_H
+#endif
