@@ -69,6 +69,37 @@ namespace FIX44
         FIELD_SET(*this, FIX::PartySubIDType);
       };
     };
+    FIELD_SET(*this, FIX::NoOrders);
+    class NoOrders: public FIX::Group
+    {
+    public:
+    NoOrders() : FIX::Group(73,11,FIX::message_order(11,37,198,526,66,756,38,799,800,0)) {}
+      FIELD_SET(*this, FIX::ClOrdID);
+      FIELD_SET(*this, FIX::OrderID);
+      FIELD_SET(*this, FIX::SecondaryOrderID);
+      FIELD_SET(*this, FIX::SecondaryClOrdID);
+      FIELD_SET(*this, FIX::ListID);
+      FIELD_SET(*this, FIX::NoNested2PartyIDs);
+      class NoNested2PartyIDs: public FIX::Group
+      {
+      public:
+      NoNested2PartyIDs() : FIX::Group(756,757,FIX::message_order(757,758,759,806,0)) {}
+        FIELD_SET(*this, FIX::Nested2PartyID);
+        FIELD_SET(*this, FIX::Nested2PartyIDSource);
+        FIELD_SET(*this, FIX::Nested2PartyRole);
+        FIELD_SET(*this, FIX::NoNested2PartySubIDs);
+        class NoNested2PartySubIDs: public FIX::Group
+        {
+        public:
+        NoNested2PartySubIDs() : FIX::Group(806,760,FIX::message_order(760,807,0)) {}
+          FIELD_SET(*this, FIX::Nested2PartySubID);
+          FIELD_SET(*this, FIX::Nested2PartySubIDType);
+        };
+      };
+      FIELD_SET(*this, FIX::OrderQty);
+      FIELD_SET(*this, FIX::OrderAvgPx);
+      FIELD_SET(*this, FIX::OrderBookingQty);
+    };
     FIELD_SET(*this, FIX::AllocID);
     FIELD_SET(*this, FIX::SecondaryAllocID);
     FIELD_SET(*this, FIX::IndividualAllocID);
@@ -87,12 +118,21 @@ namespace FIX44
     FIELD_SET(*this, FIX::SymbolSfx);
     FIELD_SET(*this, FIX::SecurityID);
     FIELD_SET(*this, FIX::SecurityIDSource);
+    FIELD_SET(*this, FIX::NoSecurityAltID);
+    class NoSecurityAltID: public FIX::Group
+    {
+    public:
+    NoSecurityAltID() : FIX::Group(454,455,FIX::message_order(455,456,0)) {}
+      FIELD_SET(*this, FIX::SecurityAltID);
+      FIELD_SET(*this, FIX::SecurityAltIDSource);
+    };
     FIELD_SET(*this, FIX::Product);
     FIELD_SET(*this, FIX::CFICode);
     FIELD_SET(*this, FIX::SecurityType);
     FIELD_SET(*this, FIX::SecuritySubType);
     FIELD_SET(*this, FIX::MaturityMonthYear);
     FIELD_SET(*this, FIX::MaturityDate);
+    FIELD_SET(*this, FIX::PutOrCall);
     FIELD_SET(*this, FIX::CouponPaymentDate);
     FIELD_SET(*this, FIX::IssueDate);
     FIELD_SET(*this, FIX::RepoCollateralSecurityType);
@@ -121,16 +161,6 @@ namespace FIX44
     FIELD_SET(*this, FIX::ContractSettlMonth);
     FIELD_SET(*this, FIX::CPProgram);
     FIELD_SET(*this, FIX::CPRegType);
-    FIELD_SET(*this, FIX::DatedDate);
-    FIELD_SET(*this, FIX::InterestAccrualDate);
-    FIELD_SET(*this, FIX::NoSecurityAltID);
-    class NoSecurityAltID: public FIX::Group
-    {
-    public:
-    NoSecurityAltID() : FIX::Group(454,455,FIX::message_order(455,456,0)) {}
-      FIELD_SET(*this, FIX::SecurityAltID);
-      FIELD_SET(*this, FIX::SecurityAltIDSource);
-    };
     FIELD_SET(*this, FIX::NoEvents);
     class NoEvents: public FIX::Group
     {
@@ -141,6 +171,8 @@ namespace FIX44
       FIELD_SET(*this, FIX::EventPx);
       FIELD_SET(*this, FIX::EventText);
     };
+    FIELD_SET(*this, FIX::DatedDate);
+    FIELD_SET(*this, FIX::InterestAccrualDate);
     FIELD_SET(*this, FIX::DeliveryForm);
     FIELD_SET(*this, FIX::PctAtRisk);
     FIELD_SET(*this, FIX::NoInstrAttrib);
@@ -160,6 +192,128 @@ namespace FIX44
     FIELD_SET(*this, FIX::EndDate);
     FIELD_SET(*this, FIX::DeliveryType);
     FIELD_SET(*this, FIX::MarginRatio);
+    FIELD_SET(*this, FIX::NoUnderlyings);
+    class NoUnderlyings: public FIX::Group
+    {
+    public:
+    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,315,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,435,308,306,362,363,307,364,365,877,878,318,879,810,882,883,884,885,886,0)) {}
+      FIELD_SET(*this, FIX::UnderlyingSymbol);
+      FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
+      FIELD_SET(*this, FIX::UnderlyingSecurityID);
+      FIELD_SET(*this, FIX::UnderlyingSecurityIDSource);
+      FIELD_SET(*this, FIX::NoUnderlyingSecurityAltID);
+      class NoUnderlyingSecurityAltID: public FIX::Group
+      {
+      public:
+      NoUnderlyingSecurityAltID() : FIX::Group(457,458,FIX::message_order(458,459,0)) {}
+        FIELD_SET(*this, FIX::UnderlyingSecurityAltID);
+        FIELD_SET(*this, FIX::UnderlyingSecurityAltIDSource);
+      };
+      FIELD_SET(*this, FIX::UnderlyingProduct);
+      FIELD_SET(*this, FIX::UnderlyingCFICode);
+      FIELD_SET(*this, FIX::UnderlyingSecurityType);
+      FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
+      FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
+      FIELD_SET(*this, FIX::UnderlyingMaturityDate);
+      FIELD_SET(*this, FIX::UnderlyingPutOrCall);
+      FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
+      FIELD_SET(*this, FIX::UnderlyingIssueDate);
+      FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
+      FIELD_SET(*this, FIX::UnderlyingRepurchaseTerm);
+      FIELD_SET(*this, FIX::UnderlyingRepurchaseRate);
+      FIELD_SET(*this, FIX::UnderlyingFactor);
+      FIELD_SET(*this, FIX::UnderlyingCreditRating);
+      FIELD_SET(*this, FIX::UnderlyingInstrRegistry);
+      FIELD_SET(*this, FIX::UnderlyingCountryOfIssue);
+      FIELD_SET(*this, FIX::UnderlyingStateOrProvinceOfIssue);
+      FIELD_SET(*this, FIX::UnderlyingLocaleOfIssue);
+      FIELD_SET(*this, FIX::UnderlyingRedemptionDate);
+      FIELD_SET(*this, FIX::UnderlyingStrikePrice);
+      FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
+      FIELD_SET(*this, FIX::UnderlyingOptAttribute);
+      FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
+      FIELD_SET(*this, FIX::UnderlyingCouponRate);
+      FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
+      FIELD_SET(*this, FIX::UnderlyingIssuer);
+      FIELD_SET(*this, FIX::EncodedUnderlyingIssuerLen);
+      FIELD_SET(*this, FIX::EncodedUnderlyingIssuer);
+      FIELD_SET(*this, FIX::UnderlyingSecurityDesc);
+      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDescLen);
+      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
+      FIELD_SET(*this, FIX::UnderlyingCPProgram);
+      FIELD_SET(*this, FIX::UnderlyingCPRegType);
+      FIELD_SET(*this, FIX::UnderlyingCurrency);
+      FIELD_SET(*this, FIX::UnderlyingQty);
+      FIELD_SET(*this, FIX::UnderlyingPx);
+      FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
+      FIELD_SET(*this, FIX::UnderlyingEndPrice);
+      FIELD_SET(*this, FIX::UnderlyingStartValue);
+      FIELD_SET(*this, FIX::UnderlyingCurrentValue);
+      FIELD_SET(*this, FIX::UnderlyingEndValue);
+      FIELD_SET(*this, FIX::NoUnderlyingStips);
+      class NoUnderlyingStips: public FIX::Group
+      {
+      public:
+      NoUnderlyingStips() : FIX::Group(887,888,FIX::message_order(888,889,0)) {}
+        FIELD_SET(*this, FIX::UnderlyingStipType);
+        FIELD_SET(*this, FIX::UnderlyingStipValue);
+      };
+    };
+    FIELD_SET(*this, FIX::NoLegs);
+    class NoLegs: public FIX::Group
+    {
+    public:
+    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,0)) {}
+      FIELD_SET(*this, FIX::LegSymbol);
+      FIELD_SET(*this, FIX::LegSymbolSfx);
+      FIELD_SET(*this, FIX::LegSecurityID);
+      FIELD_SET(*this, FIX::LegSecurityIDSource);
+      FIELD_SET(*this, FIX::NoLegSecurityAltID);
+      class NoLegSecurityAltID: public FIX::Group
+      {
+      public:
+      NoLegSecurityAltID() : FIX::Group(604,605,FIX::message_order(605,606,0)) {}
+        FIELD_SET(*this, FIX::LegSecurityAltID);
+        FIELD_SET(*this, FIX::LegSecurityAltIDSource);
+      };
+      FIELD_SET(*this, FIX::LegProduct);
+      FIELD_SET(*this, FIX::LegCFICode);
+      FIELD_SET(*this, FIX::LegSecurityType);
+      FIELD_SET(*this, FIX::LegSecuritySubType);
+      FIELD_SET(*this, FIX::LegMaturityMonthYear);
+      FIELD_SET(*this, FIX::LegMaturityDate);
+      FIELD_SET(*this, FIX::LegCouponPaymentDate);
+      FIELD_SET(*this, FIX::LegIssueDate);
+      FIELD_SET(*this, FIX::LegRepoCollateralSecurityType);
+      FIELD_SET(*this, FIX::LegRepurchaseTerm);
+      FIELD_SET(*this, FIX::LegRepurchaseRate);
+      FIELD_SET(*this, FIX::LegFactor);
+      FIELD_SET(*this, FIX::LegCreditRating);
+      FIELD_SET(*this, FIX::LegInstrRegistry);
+      FIELD_SET(*this, FIX::LegCountryOfIssue);
+      FIELD_SET(*this, FIX::LegStateOrProvinceOfIssue);
+      FIELD_SET(*this, FIX::LegLocaleOfIssue);
+      FIELD_SET(*this, FIX::LegRedemptionDate);
+      FIELD_SET(*this, FIX::LegStrikePrice);
+      FIELD_SET(*this, FIX::LegStrikeCurrency);
+      FIELD_SET(*this, FIX::LegOptAttribute);
+      FIELD_SET(*this, FIX::LegContractMultiplier);
+      FIELD_SET(*this, FIX::LegCouponRate);
+      FIELD_SET(*this, FIX::LegSecurityExchange);
+      FIELD_SET(*this, FIX::LegIssuer);
+      FIELD_SET(*this, FIX::EncodedLegIssuerLen);
+      FIELD_SET(*this, FIX::EncodedLegIssuer);
+      FIELD_SET(*this, FIX::LegSecurityDesc);
+      FIELD_SET(*this, FIX::EncodedLegSecurityDescLen);
+      FIELD_SET(*this, FIX::EncodedLegSecurityDesc);
+      FIELD_SET(*this, FIX::LegRatioQty);
+      FIELD_SET(*this, FIX::LegSide);
+      FIELD_SET(*this, FIX::LegCurrency);
+      FIELD_SET(*this, FIX::LegPool);
+      FIELD_SET(*this, FIX::LegDatedDate);
+      FIELD_SET(*this, FIX::LegContractSettlMonth);
+      FIELD_SET(*this, FIX::LegInterestAccrualDate);
+    };
     FIELD_SET(*this, FIX::YieldType);
     FIELD_SET(*this, FIX::Yield);
     FIELD_SET(*this, FIX::YieldCalcDate);
@@ -171,6 +325,15 @@ namespace FIX44
     FIELD_SET(*this, FIX::Side);
     FIELD_SET(*this, FIX::Currency);
     FIELD_SET(*this, FIX::LastMkt);
+    FIELD_SET(*this, FIX::NoCapacities);
+    class NoCapacities: public FIX::Group
+    {
+    public:
+    NoCapacities() : FIX::Group(862,528,FIX::message_order(528,529,863,0)) {}
+      FIELD_SET(*this, FIX::OrderCapacity);
+      FIELD_SET(*this, FIX::OrderRestrictions);
+      FIELD_SET(*this, FIX::OrderCapacityQty);
+    };
     FIELD_SET(*this, FIX::AllocAccount);
     FIELD_SET(*this, FIX::AllocAcctIDSource);
     FIELD_SET(*this, FIX::AllocAccountType);
@@ -252,159 +415,6 @@ namespace FIX44
       FIELD_SET(*this, FIX::StipulationType);
       FIELD_SET(*this, FIX::StipulationValue);
     };
-    FIELD_SET(*this, FIX::NoOrders);
-    class NoOrders: public FIX::Group
-    {
-    public:
-    NoOrders() : FIX::Group(73,11,FIX::message_order(11,37,198,526,66,756,38,799,800,0)) {}
-      FIELD_SET(*this, FIX::ClOrdID);
-      FIELD_SET(*this, FIX::OrderID);
-      FIELD_SET(*this, FIX::SecondaryOrderID);
-      FIELD_SET(*this, FIX::SecondaryClOrdID);
-      FIELD_SET(*this, FIX::ListID);
-      FIELD_SET(*this, FIX::NoNested2PartyIDs);
-      class NoNested2PartyIDs: public FIX::Group
-      {
-      public:
-      NoNested2PartyIDs() : FIX::Group(756,757,FIX::message_order(757,758,759,806,0)) {}
-        FIELD_SET(*this, FIX::Nested2PartyID);
-        FIELD_SET(*this, FIX::Nested2PartyIDSource);
-        FIELD_SET(*this, FIX::Nested2PartyRole);
-        FIELD_SET(*this, FIX::NoNested2PartySubIDs);
-        class NoNested2PartySubIDs: public FIX::Group
-        {
-        public:
-        NoNested2PartySubIDs() : FIX::Group(806,760,FIX::message_order(760,807,0)) {}
-          FIELD_SET(*this, FIX::Nested2PartySubID);
-          FIELD_SET(*this, FIX::Nested2PartySubIDType);
-        };
-      };
-      FIELD_SET(*this, FIX::OrderQty);
-      FIELD_SET(*this, FIX::OrderAvgPx);
-      FIELD_SET(*this, FIX::OrderBookingQty);
-    };
-    FIELD_SET(*this, FIX::NoUnderlyings);
-    class NoUnderlyings: public FIX::Group
-    {
-    public:
-    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,457,462,463,310,763,313,542,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,435,308,306,362,363,307,364,365,877,878,318,879,810,882,883,884,885,886,0)) {}
-      FIELD_SET(*this, FIX::UnderlyingSymbol);
-      FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
-      FIELD_SET(*this, FIX::UnderlyingSecurityID);
-      FIELD_SET(*this, FIX::UnderlyingSecurityIDSource);
-      FIELD_SET(*this, FIX::UnderlyingProduct);
-      FIELD_SET(*this, FIX::UnderlyingCFICode);
-      FIELD_SET(*this, FIX::UnderlyingSecurityType);
-      FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
-      FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
-      FIELD_SET(*this, FIX::UnderlyingMaturityDate);
-      FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
-      FIELD_SET(*this, FIX::UnderlyingIssueDate);
-      FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
-      FIELD_SET(*this, FIX::UnderlyingRepurchaseTerm);
-      FIELD_SET(*this, FIX::UnderlyingRepurchaseRate);
-      FIELD_SET(*this, FIX::UnderlyingFactor);
-      FIELD_SET(*this, FIX::UnderlyingCreditRating);
-      FIELD_SET(*this, FIX::UnderlyingInstrRegistry);
-      FIELD_SET(*this, FIX::UnderlyingCountryOfIssue);
-      FIELD_SET(*this, FIX::UnderlyingStateOrProvinceOfIssue);
-      FIELD_SET(*this, FIX::UnderlyingLocaleOfIssue);
-      FIELD_SET(*this, FIX::UnderlyingRedemptionDate);
-      FIELD_SET(*this, FIX::UnderlyingStrikePrice);
-      FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
-      FIELD_SET(*this, FIX::UnderlyingOptAttribute);
-      FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
-      FIELD_SET(*this, FIX::UnderlyingCouponRate);
-      FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
-      FIELD_SET(*this, FIX::UnderlyingIssuer);
-      FIELD_SET(*this, FIX::EncodedUnderlyingIssuerLen);
-      FIELD_SET(*this, FIX::EncodedUnderlyingIssuer);
-      FIELD_SET(*this, FIX::UnderlyingSecurityDesc);
-      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDescLen);
-      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
-      FIELD_SET(*this, FIX::UnderlyingCPProgram);
-      FIELD_SET(*this, FIX::UnderlyingCPRegType);
-      FIELD_SET(*this, FIX::UnderlyingCurrency);
-      FIELD_SET(*this, FIX::UnderlyingQty);
-      FIELD_SET(*this, FIX::UnderlyingPx);
-      FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
-      FIELD_SET(*this, FIX::UnderlyingEndPrice);
-      FIELD_SET(*this, FIX::UnderlyingStartValue);
-      FIELD_SET(*this, FIX::UnderlyingCurrentValue);
-      FIELD_SET(*this, FIX::UnderlyingEndValue);
-      FIELD_SET(*this, FIX::NoUnderlyingSecurityAltID);
-      class NoUnderlyingSecurityAltID: public FIX::Group
-      {
-      public:
-      NoUnderlyingSecurityAltID() : FIX::Group(457,458,FIX::message_order(458,459,0)) {}
-        FIELD_SET(*this, FIX::UnderlyingSecurityAltID);
-        FIELD_SET(*this, FIX::UnderlyingSecurityAltIDSource);
-      };
-    };
-    FIELD_SET(*this, FIX::NoLegs);
-    class NoLegs: public FIX::Group
-    {
-    public:
-    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,604,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,0)) {}
-      FIELD_SET(*this, FIX::LegSymbol);
-      FIELD_SET(*this, FIX::LegSymbolSfx);
-      FIELD_SET(*this, FIX::LegSecurityID);
-      FIELD_SET(*this, FIX::LegSecurityIDSource);
-      FIELD_SET(*this, FIX::LegProduct);
-      FIELD_SET(*this, FIX::LegCFICode);
-      FIELD_SET(*this, FIX::LegSecurityType);
-      FIELD_SET(*this, FIX::LegSecuritySubType);
-      FIELD_SET(*this, FIX::LegMaturityMonthYear);
-      FIELD_SET(*this, FIX::LegMaturityDate);
-      FIELD_SET(*this, FIX::LegCouponPaymentDate);
-      FIELD_SET(*this, FIX::LegIssueDate);
-      FIELD_SET(*this, FIX::LegRepoCollateralSecurityType);
-      FIELD_SET(*this, FIX::LegRepurchaseTerm);
-      FIELD_SET(*this, FIX::LegRepurchaseRate);
-      FIELD_SET(*this, FIX::LegFactor);
-      FIELD_SET(*this, FIX::LegCreditRating);
-      FIELD_SET(*this, FIX::LegInstrRegistry);
-      FIELD_SET(*this, FIX::LegCountryOfIssue);
-      FIELD_SET(*this, FIX::LegStateOrProvinceOfIssue);
-      FIELD_SET(*this, FIX::LegLocaleOfIssue);
-      FIELD_SET(*this, FIX::LegRedemptionDate);
-      FIELD_SET(*this, FIX::LegStrikePrice);
-      FIELD_SET(*this, FIX::LegStrikeCurrency);
-      FIELD_SET(*this, FIX::LegOptAttribute);
-      FIELD_SET(*this, FIX::LegContractMultiplier);
-      FIELD_SET(*this, FIX::LegCouponRate);
-      FIELD_SET(*this, FIX::LegSecurityExchange);
-      FIELD_SET(*this, FIX::LegIssuer);
-      FIELD_SET(*this, FIX::EncodedLegIssuerLen);
-      FIELD_SET(*this, FIX::EncodedLegIssuer);
-      FIELD_SET(*this, FIX::LegSecurityDesc);
-      FIELD_SET(*this, FIX::EncodedLegSecurityDescLen);
-      FIELD_SET(*this, FIX::EncodedLegSecurityDesc);
-      FIELD_SET(*this, FIX::LegRatioQty);
-      FIELD_SET(*this, FIX::LegSide);
-      FIELD_SET(*this, FIX::LegCurrency);
-      FIELD_SET(*this, FIX::LegPool);
-      FIELD_SET(*this, FIX::LegDatedDate);
-      FIELD_SET(*this, FIX::LegContractSettlMonth);
-      FIELD_SET(*this, FIX::LegInterestAccrualDate);
-      FIELD_SET(*this, FIX::NoLegSecurityAltID);
-      class NoLegSecurityAltID: public FIX::Group
-      {
-      public:
-      NoLegSecurityAltID() : FIX::Group(604,605,FIX::message_order(605,606,0)) {}
-        FIELD_SET(*this, FIX::LegSecurityAltID);
-        FIELD_SET(*this, FIX::LegSecurityAltIDSource);
-      };
-    };
-    FIELD_SET(*this, FIX::NoCapacities);
-    class NoCapacities: public FIX::Group
-    {
-    public:
-    NoCapacities() : FIX::Group(862,528,FIX::message_order(528,529,863,0)) {}
-      FIELD_SET(*this, FIX::OrderCapacity);
-      FIELD_SET(*this, FIX::OrderRestrictions);
-      FIELD_SET(*this, FIX::OrderCapacityQty);
-    };
     FIELD_SET(*this, FIX::NoMiscFees);
     class NoMiscFees: public FIX::Group
     {
