@@ -30,6 +30,14 @@ namespace FIX44
     FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
     FIELD_SET(*this, FIX::UnderlyingSecurityID);
     FIELD_SET(*this, FIX::UnderlyingSecurityIDSource);
+    FIELD_SET(*this, FIX::NoUnderlyingSecurityAltID);
+    class NoUnderlyingSecurityAltID: public FIX::Group
+    {
+    public:
+    NoUnderlyingSecurityAltID() : FIX::Group(457,458,FIX::message_order(458,459,0)) {}
+      FIELD_SET(*this, FIX::UnderlyingSecurityAltID);
+      FIELD_SET(*this, FIX::UnderlyingSecurityAltIDSource);
+    };
     FIELD_SET(*this, FIX::UnderlyingProduct);
     FIELD_SET(*this, FIX::UnderlyingCFICode);
     FIELD_SET(*this, FIX::UnderlyingSecurityType);
@@ -71,6 +79,14 @@ namespace FIX44
     FIELD_SET(*this, FIX::UnderlyingStartValue);
     FIELD_SET(*this, FIX::UnderlyingCurrentValue);
     FIELD_SET(*this, FIX::UnderlyingEndValue);
+    FIELD_SET(*this, FIX::NoUnderlyingStips);
+    class NoUnderlyingStips: public FIX::Group
+    {
+    public:
+    NoUnderlyingStips() : FIX::Group(887,888,FIX::message_order(888,889,0)) {}
+      FIELD_SET(*this, FIX::UnderlyingStipType);
+      FIELD_SET(*this, FIX::UnderlyingStipValue);
+    };
     FIELD_SET(*this, FIX::SecuritySubType);
     FIELD_SET(*this, FIX::Currency);
     FIELD_SET(*this, FIX::Text);
