@@ -30,6 +30,14 @@ namespace FIX50
     FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
     FIELD_SET(*this, FIX::UnderlyingSecurityID);
     FIELD_SET(*this, FIX::UnderlyingSecurityIDSource);
+    FIELD_SET(*this, FIX::NoUnderlyingSecurityAltID);
+    class NoUnderlyingSecurityAltID: public FIX::Group
+    {
+    public:
+    NoUnderlyingSecurityAltID() : FIX::Group(457,458,FIX::message_order(458,459,0)) {}
+      FIELD_SET(*this, FIX::UnderlyingSecurityAltID);
+      FIELD_SET(*this, FIX::UnderlyingSecurityAltIDSource);
+    };
     FIELD_SET(*this, FIX::UnderlyingProduct);
     FIELD_SET(*this, FIX::UnderlyingCFICode);
     FIELD_SET(*this, FIX::UnderlyingSecurityType);
@@ -77,10 +85,35 @@ namespace FIX50
     FIELD_SET(*this, FIX::UnderlyingStartValue);
     FIELD_SET(*this, FIX::UnderlyingCurrentValue);
     FIELD_SET(*this, FIX::UnderlyingEndValue);
+    FIELD_SET(*this, FIX::NoUnderlyingStips);
+    class NoUnderlyingStips: public FIX::Group
+    {
+    public:
+    NoUnderlyingStips() : FIX::Group(887,888,FIX::message_order(888,889,0)) {}
+      FIELD_SET(*this, FIX::UnderlyingStipType);
+      FIELD_SET(*this, FIX::UnderlyingStipValue);
+    };
     FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
     FIELD_SET(*this, FIX::UnderlyingFXRate);
     FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
     FIELD_SET(*this, FIX::UnderlyingCapValue);
+    FIELD_SET(*this, FIX::NoUndlyInstrumentParties);
+    class NoUndlyInstrumentParties: public FIX::Group
+    {
+    public:
+    NoUndlyInstrumentParties() : FIX::Group(1058,1059,FIX::message_order(1059,1060,1061,1062,0)) {}
+      FIELD_SET(*this, FIX::UndlyInstrumentPartyID);
+      FIELD_SET(*this, FIX::UndlyInstrumentPartyIDSource);
+      FIELD_SET(*this, FIX::UndlyInstrumentPartyRole);
+      FIELD_SET(*this, FIX::NoUndlyInstrumentPartySubIDs);
+      class NoUndlyInstrumentPartySubIDs: public FIX::Group
+      {
+      public:
+      NoUndlyInstrumentPartySubIDs() : FIX::Group(1062,1063,FIX::message_order(1063,1064,0)) {}
+        FIELD_SET(*this, FIX::UndlyInstrumentPartySubID);
+        FIELD_SET(*this, FIX::UndlyInstrumentPartySubIDType);
+      };
+    };
     FIELD_SET(*this, FIX::UnderlyingSettlMethod);
     FIELD_SET(*this, FIX::SecuritySubType);
     FIELD_SET(*this, FIX::Currency);
