@@ -21,7 +21,8 @@ namespace FIX50
   public:
     Message( const FIX::MsgType& msgtype )
     : FIX::Message(
-      FIX::BeginString("FIXT.1.1"), msgtype ) {}
+      FIX::BeginString("FIXT.1.1"), msgtype )
+     { getHeader().setField( FIX::ApplVerID("7") ); }
 
     Message(const FIX::Message& m) : FIX::Message(m) {}
     Message(const Message& m) : FIX::Message(m) {}
