@@ -1,7 +1,7 @@
 /* -*- C++ -*- */
  
 /****************************************************************************
-** Copyright (c) quickfixengine.org  All rights reserved.
+** Copyright (c) 2001-2014
 **
 ** This file is part of the QuickFIX FIX Engine
 **
@@ -22,8 +22,10 @@
 #ifndef FIX50_MESSAGECRACKER_H
 #define FIX50_MESSAGECRACKER_H
 
+
 #include "../SessionID.h"
 #include "../Exceptions.h"
+
 #include "../fix50/Message.h"
 
 namespace FIX50
@@ -989,4 +991,4 @@ void crack( Message& message,
   };
 }
 
-#endif //FIX50_MESSAGECRACKER_H
+#endif
