@@ -83,6 +83,14 @@ namespace FIX50SP1
       FIELD_SET(*this, FIX::SymbolSfx);
       FIELD_SET(*this, FIX::SecurityID);
       FIELD_SET(*this, FIX::SecurityIDSource);
+      FIELD_SET(*this, FIX::NoSecurityAltID);
+      class NoSecurityAltID: public FIX::Group
+      {
+      public:
+      NoSecurityAltID() : FIX::Group(454,455,FIX::message_order(455,456,0)) {}
+        FIELD_SET(*this, FIX::SecurityAltID);
+        FIELD_SET(*this, FIX::SecurityAltIDSource);
+      };
       FIELD_SET(*this, FIX::Product);
       FIELD_SET(*this, FIX::ProductComplex);
       FIELD_SET(*this, FIX::SecurityGroup);
@@ -141,12 +149,43 @@ namespace FIX50SP1
       FIELD_SET(*this, FIX::SecurityDesc);
       FIELD_SET(*this, FIX::EncodedSecurityDescLen);
       FIELD_SET(*this, FIX::EncodedSecurityDesc);
+      FIELD_SET(*this, FIX::SecurityXMLLen);
+      FIELD_SET(*this, FIX::SecurityXML);
+      FIELD_SET(*this, FIX::SecurityXMLSchema);
       FIELD_SET(*this, FIX::Pool);
       FIELD_SET(*this, FIX::ContractSettlMonth);
       FIELD_SET(*this, FIX::CPProgram);
       FIELD_SET(*this, FIX::CPRegType);
+      FIELD_SET(*this, FIX::NoEvents);
+      class NoEvents: public FIX::Group
+      {
+      public:
+      NoEvents() : FIX::Group(864,865,FIX::message_order(865,866,1145,867,868,0)) {}
+        FIELD_SET(*this, FIX::EventType);
+        FIELD_SET(*this, FIX::EventDate);
+        FIELD_SET(*this, FIX::EventTime);
+        FIELD_SET(*this, FIX::EventPx);
+        FIELD_SET(*this, FIX::EventText);
+      };
       FIELD_SET(*this, FIX::DatedDate);
       FIELD_SET(*this, FIX::InterestAccrualDate);
+      FIELD_SET(*this, FIX::NoInstrumentParties);
+      class NoInstrumentParties: public FIX::Group
+      {
+      public:
+      NoInstrumentParties() : FIX::Group(1018,1019,FIX::message_order(1019,1050,1051,1052,0)) {}
+        FIELD_SET(*this, FIX::InstrumentPartyID);
+        FIELD_SET(*this, FIX::InstrumentPartyIDSource);
+        FIELD_SET(*this, FIX::InstrumentPartyRole);
+        FIELD_SET(*this, FIX::NoInstrumentPartySubIDs);
+        class NoInstrumentPartySubIDs: public FIX::Group
+        {
+        public:
+        NoInstrumentPartySubIDs() : FIX::Group(1052,1053,FIX::message_order(1053,1054,0)) {}
+          FIELD_SET(*this, FIX::InstrumentPartySubID);
+          FIELD_SET(*this, FIX::InstrumentPartySubIDType);
+        };
+      };
     };
     FIELD_SET(*this, FIX::SettlPrice);
     FIELD_SET(*this, FIX::PriorSettlPrice);
