@@ -50,6 +50,16 @@ namespace FIX50SP1
     FIELD_SET(*this, FIX::AllocLinkID);
     FIELD_SET(*this, FIX::AllocLinkType);
     FIELD_SET(*this, FIX::BookingRefID);
+    FIELD_SET(*this, FIX::ClearingBusinessDate);
+    FIELD_SET(*this, FIX::TrdType);
+    FIELD_SET(*this, FIX::TrdSubType);
+    FIELD_SET(*this, FIX::MultiLegReportingType);
+    FIELD_SET(*this, FIX::CustOrderCapacity);
+    FIELD_SET(*this, FIX::TradeInputSource);
+    FIELD_SET(*this, FIX::RndPx);
+    FIELD_SET(*this, FIX::MessageEventSource);
+    FIELD_SET(*this, FIX::TradeInputDevice);
+    FIELD_SET(*this, FIX::AvgPxIndicator);
     FIELD_SET(*this, FIX::AllocNoOrdersType);
     FIELD_SET(*this, FIX::NoOrders);
     class NoOrders: public FIX::Group
@@ -104,12 +114,26 @@ namespace FIX50SP1
     FIELD_SET(*this, FIX::SymbolSfx);
     FIELD_SET(*this, FIX::SecurityID);
     FIELD_SET(*this, FIX::SecurityIDSource);
+    FIELD_SET(*this, FIX::NoSecurityAltID);
+    class NoSecurityAltID: public FIX::Group
+    {
+    public:
+    NoSecurityAltID() : FIX::Group(454,455,FIX::message_order(455,456,0)) {}
+      FIELD_SET(*this, FIX::SecurityAltID);
+      FIELD_SET(*this, FIX::SecurityAltIDSource);
+    };
     FIELD_SET(*this, FIX::Product);
+    FIELD_SET(*this, FIX::ProductComplex);
+    FIELD_SET(*this, FIX::SecurityGroup);
     FIELD_SET(*this, FIX::CFICode);
     FIELD_SET(*this, FIX::SecurityType);
     FIELD_SET(*this, FIX::SecuritySubType);
     FIELD_SET(*this, FIX::MaturityMonthYear);
     FIELD_SET(*this, FIX::MaturityDate);
+    FIELD_SET(*this, FIX::MaturityTime);
+    FIELD_SET(*this, FIX::SettleOnOpenFlag);
+    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
+    FIELD_SET(*this, FIX::SecurityStatus);
     FIELD_SET(*this, FIX::CouponPaymentDate);
     FIELD_SET(*this, FIX::IssueDate);
     FIELD_SET(*this, FIX::RepoCollateralSecurityType);
@@ -124,52 +148,85 @@ namespace FIX50SP1
     FIELD_SET(*this, FIX::RedemptionDate);
     FIELD_SET(*this, FIX::StrikePrice);
     FIELD_SET(*this, FIX::StrikeCurrency);
-    FIELD_SET(*this, FIX::OptAttribute);
-    FIELD_SET(*this, FIX::ContractMultiplier);
-    FIELD_SET(*this, FIX::CouponRate);
-    FIELD_SET(*this, FIX::SecurityExchange);
-    FIELD_SET(*this, FIX::Issuer);
-    FIELD_SET(*this, FIX::EncodedIssuerLen);
-    FIELD_SET(*this, FIX::EncodedIssuer);
-    FIELD_SET(*this, FIX::SecurityDesc);
-    FIELD_SET(*this, FIX::EncodedSecurityDescLen);
-    FIELD_SET(*this, FIX::EncodedSecurityDesc);
-    FIELD_SET(*this, FIX::Pool);
-    FIELD_SET(*this, FIX::ContractSettlMonth);
-    FIELD_SET(*this, FIX::CPProgram);
-    FIELD_SET(*this, FIX::CPRegType);
-    FIELD_SET(*this, FIX::DatedDate);
-    FIELD_SET(*this, FIX::InterestAccrualDate);
-    FIELD_SET(*this, FIX::SecurityStatus);
-    FIELD_SET(*this, FIX::SettleOnOpenFlag);
-    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
     FIELD_SET(*this, FIX::StrikeMultiplier);
     FIELD_SET(*this, FIX::StrikeValue);
+    FIELD_SET(*this, FIX::OptAttribute);
+    FIELD_SET(*this, FIX::ContractMultiplier);
     FIELD_SET(*this, FIX::MinPriceIncrement);
-    FIELD_SET(*this, FIX::PositionLimit);
-    FIELD_SET(*this, FIX::NTPositionLimit);
-    FIELD_SET(*this, FIX::UnitOfMeasure);
-    FIELD_SET(*this, FIX::TimeUnit);
-    FIELD_SET(*this, FIX::MaturityTime);
-    FIELD_SET(*this, FIX::SecurityGroup);
     FIELD_SET(*this, FIX::MinPriceIncrementAmount);
+    FIELD_SET(*this, FIX::UnitOfMeasure);
     FIELD_SET(*this, FIX::UnitOfMeasureQty);
-    FIELD_SET(*this, FIX::ProductComplex);
     FIELD_SET(*this, FIX::PriceUnitOfMeasure);
     FIELD_SET(*this, FIX::PriceUnitOfMeasureQty);
     FIELD_SET(*this, FIX::SettlMethod);
     FIELD_SET(*this, FIX::ExerciseStyle);
     FIELD_SET(*this, FIX::OptPayAmount);
     FIELD_SET(*this, FIX::PriceQuoteMethod);
+    FIELD_SET(*this, FIX::FuturesValuationMethod);
     FIELD_SET(*this, FIX::ListMethod);
     FIELD_SET(*this, FIX::CapPrice);
     FIELD_SET(*this, FIX::FloorPrice);
     FIELD_SET(*this, FIX::PutOrCall);
     FIELD_SET(*this, FIX::FlexibleIndicator);
     FIELD_SET(*this, FIX::FlexProductEligibilityIndicator);
-    FIELD_SET(*this, FIX::FuturesValuationMethod);
+    FIELD_SET(*this, FIX::TimeUnit);
+    FIELD_SET(*this, FIX::CouponRate);
+    FIELD_SET(*this, FIX::SecurityExchange);
+    FIELD_SET(*this, FIX::PositionLimit);
+    FIELD_SET(*this, FIX::NTPositionLimit);
+    FIELD_SET(*this, FIX::Issuer);
+    FIELD_SET(*this, FIX::EncodedIssuerLen);
+    FIELD_SET(*this, FIX::EncodedIssuer);
+    FIELD_SET(*this, FIX::SecurityDesc);
+    FIELD_SET(*this, FIX::EncodedSecurityDescLen);
+    FIELD_SET(*this, FIX::EncodedSecurityDesc);
+    FIELD_SET(*this, FIX::SecurityXMLLen);
+    FIELD_SET(*this, FIX::SecurityXML);
+    FIELD_SET(*this, FIX::SecurityXMLSchema);
+    FIELD_SET(*this, FIX::Pool);
+    FIELD_SET(*this, FIX::ContractSettlMonth);
+    FIELD_SET(*this, FIX::CPProgram);
+    FIELD_SET(*this, FIX::CPRegType);
+    FIELD_SET(*this, FIX::NoEvents);
+    class NoEvents: public FIX::Group
+    {
+    public:
+    NoEvents() : FIX::Group(864,865,FIX::message_order(865,866,1145,867,868,0)) {}
+      FIELD_SET(*this, FIX::EventType);
+      FIELD_SET(*this, FIX::EventDate);
+      FIELD_SET(*this, FIX::EventTime);
+      FIELD_SET(*this, FIX::EventPx);
+      FIELD_SET(*this, FIX::EventText);
+    };
+    FIELD_SET(*this, FIX::DatedDate);
+    FIELD_SET(*this, FIX::InterestAccrualDate);
+    FIELD_SET(*this, FIX::NoInstrumentParties);
+    class NoInstrumentParties: public FIX::Group
+    {
+    public:
+    NoInstrumentParties() : FIX::Group(1018,1019,FIX::message_order(1019,1050,1051,1052,0)) {}
+      FIELD_SET(*this, FIX::InstrumentPartyID);
+      FIELD_SET(*this, FIX::InstrumentPartyIDSource);
+      FIELD_SET(*this, FIX::InstrumentPartyRole);
+      FIELD_SET(*this, FIX::NoInstrumentPartySubIDs);
+      class NoInstrumentPartySubIDs: public FIX::Group
+      {
+      public:
+      NoInstrumentPartySubIDs() : FIX::Group(1052,1053,FIX::message_order(1053,1054,0)) {}
+        FIELD_SET(*this, FIX::InstrumentPartySubID);
+        FIELD_SET(*this, FIX::InstrumentPartySubIDType);
+      };
+    };
     FIELD_SET(*this, FIX::DeliveryForm);
     FIELD_SET(*this, FIX::PctAtRisk);
+    FIELD_SET(*this, FIX::NoInstrAttrib);
+    class NoInstrAttrib: public FIX::Group
+    {
+    public:
+    NoInstrAttrib() : FIX::Group(870,871,FIX::message_order(871,872,0)) {}
+      FIELD_SET(*this, FIX::InstrAttribType);
+      FIELD_SET(*this, FIX::InstrAttribValue);
+    };
     FIELD_SET(*this, FIX::AgreementDesc);
     FIELD_SET(*this, FIX::AgreementID);
     FIELD_SET(*this, FIX::AgreementDate);
@@ -183,17 +240,26 @@ namespace FIX50SP1
     class NoUnderlyings: public FIX::Group
     {
     public:
-    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,435,308,306,362,363,307,364,365,877,878,318,879,810,882,883,884,885,886,972,975,973,974,998,1000,1038,1039,1044,1045,1046,1213,315,1419,1423,1424,1425,0)) {}
+    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,1213,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,998,1423,1424,1425,1000,1419,435,308,306,362,363,307,364,365,877,878,972,318,879,975,973,974,810,882,883,884,885,886,1044,1045,1046,1038,1039,315,0)) {}
       FIELD_SET(*this, FIX::UnderlyingSymbol);
       FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
       FIELD_SET(*this, FIX::UnderlyingSecurityID);
       FIELD_SET(*this, FIX::UnderlyingSecurityIDSource);
+      FIELD_SET(*this, FIX::NoUnderlyingSecurityAltID);
+      class NoUnderlyingSecurityAltID: public FIX::Group
+      {
+      public:
+      NoUnderlyingSecurityAltID() : FIX::Group(457,458,FIX::message_order(458,459,0)) {}
+        FIELD_SET(*this, FIX::UnderlyingSecurityAltID);
+        FIELD_SET(*this, FIX::UnderlyingSecurityAltIDSource);
+      };
       FIELD_SET(*this, FIX::UnderlyingProduct);
       FIELD_SET(*this, FIX::UnderlyingCFICode);
       FIELD_SET(*this, FIX::UnderlyingSecurityType);
       FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
       FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
       FIELD_SET(*this, FIX::UnderlyingMaturityDate);
+      FIELD_SET(*this, FIX::UnderlyingMaturityTime);
       FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
       FIELD_SET(*this, FIX::UnderlyingIssueDate);
       FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
@@ -210,6 +276,12 @@ namespace FIX50SP1
       FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
       FIELD_SET(*this, FIX::UnderlyingOptAttribute);
       FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
+      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
+      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasure);
+      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
+      FIELD_SET(*this, FIX::UnderlyingExerciseStyle);
       FIELD_SET(*this, FIX::UnderlyingCouponRate);
       FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
       FIELD_SET(*this, FIX::UnderlyingIssuer);
@@ -220,47 +292,74 @@ namespace FIX50SP1
       FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
       FIELD_SET(*this, FIX::UnderlyingCPProgram);
       FIELD_SET(*this, FIX::UnderlyingCPRegType);
+      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
       FIELD_SET(*this, FIX::UnderlyingCurrency);
       FIELD_SET(*this, FIX::UnderlyingQty);
+      FIELD_SET(*this, FIX::UnderlyingSettlementType);
+      FIELD_SET(*this, FIX::UnderlyingCashAmount);
+      FIELD_SET(*this, FIX::UnderlyingCashType);
       FIELD_SET(*this, FIX::UnderlyingPx);
       FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
       FIELD_SET(*this, FIX::UnderlyingEndPrice);
       FIELD_SET(*this, FIX::UnderlyingStartValue);
       FIELD_SET(*this, FIX::UnderlyingCurrentValue);
       FIELD_SET(*this, FIX::UnderlyingEndValue);
-      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
-      FIELD_SET(*this, FIX::UnderlyingSettlementType);
-      FIELD_SET(*this, FIX::UnderlyingCashAmount);
-      FIELD_SET(*this, FIX::UnderlyingCashType);
-      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
-      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
-      FIELD_SET(*this, FIX::UnderlyingCapValue);
-      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
+      FIELD_SET(*this, FIX::NoUnderlyingStips);
+      class NoUnderlyingStips: public FIX::Group
+      {
+      public:
+      NoUnderlyingStips() : FIX::Group(887,888,FIX::message_order(888,889,0)) {}
+        FIELD_SET(*this, FIX::UnderlyingStipType);
+        FIELD_SET(*this, FIX::UnderlyingStipValue);
+      };
       FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
       FIELD_SET(*this, FIX::UnderlyingFXRate);
       FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
-      FIELD_SET(*this, FIX::UnderlyingMaturityTime);
+      FIELD_SET(*this, FIX::UnderlyingCapValue);
+      FIELD_SET(*this, FIX::NoUndlyInstrumentParties);
+      class NoUndlyInstrumentParties: public FIX::Group
+      {
+      public:
+      NoUndlyInstrumentParties() : FIX::Group(1058,1059,FIX::message_order(1059,1060,1061,1062,0)) {}
+        FIELD_SET(*this, FIX::UndlyInstrumentPartyID);
+        FIELD_SET(*this, FIX::UndlyInstrumentPartyIDSource);
+        FIELD_SET(*this, FIX::UndlyInstrumentPartyRole);
+        FIELD_SET(*this, FIX::NoUndlyInstrumentPartySubIDs);
+        class NoUndlyInstrumentPartySubIDs: public FIX::Group
+        {
+        public:
+        NoUndlyInstrumentPartySubIDs() : FIX::Group(1062,1063,FIX::message_order(1063,1064,0)) {}
+          FIELD_SET(*this, FIX::UndlyInstrumentPartySubID);
+          FIELD_SET(*this, FIX::UndlyInstrumentPartySubIDType);
+        };
+      };
+      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
       FIELD_SET(*this, FIX::UnderlyingPutOrCall);
-      FIELD_SET(*this, FIX::UnderlyingExerciseStyle);
-      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasureQty);
-      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasure);
-      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasureQty);
     };
     FIELD_SET(*this, FIX::NoLegs);
     class NoLegs: public FIX::Group
     {
     public:
-    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,999,1001,1017,566,1212,1358,1420,1224,1421,1422,0)) {}
+    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,1212,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,999,1224,1421,1422,1001,1420,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,1358,1017,0)) {}
       FIELD_SET(*this, FIX::LegSymbol);
       FIELD_SET(*this, FIX::LegSymbolSfx);
       FIELD_SET(*this, FIX::LegSecurityID);
       FIELD_SET(*this, FIX::LegSecurityIDSource);
+      FIELD_SET(*this, FIX::NoLegSecurityAltID);
+      class NoLegSecurityAltID: public FIX::Group
+      {
+      public:
+      NoLegSecurityAltID() : FIX::Group(604,605,FIX::message_order(605,606,0)) {}
+        FIELD_SET(*this, FIX::LegSecurityAltID);
+        FIELD_SET(*this, FIX::LegSecurityAltIDSource);
+      };
       FIELD_SET(*this, FIX::LegProduct);
       FIELD_SET(*this, FIX::LegCFICode);
       FIELD_SET(*this, FIX::LegSecurityType);
       FIELD_SET(*this, FIX::LegSecuritySubType);
       FIELD_SET(*this, FIX::LegMaturityMonthYear);
       FIELD_SET(*this, FIX::LegMaturityDate);
+      FIELD_SET(*this, FIX::LegMaturityTime);
       FIELD_SET(*this, FIX::LegCouponPaymentDate);
       FIELD_SET(*this, FIX::LegIssueDate);
       FIELD_SET(*this, FIX::LegRepoCollateralSecurityType);
@@ -277,6 +376,12 @@ namespace FIX50SP1
       FIELD_SET(*this, FIX::LegStrikeCurrency);
       FIELD_SET(*this, FIX::LegOptAttribute);
       FIELD_SET(*this, FIX::LegContractMultiplier);
+      FIELD_SET(*this, FIX::LegUnitOfMeasure);
+      FIELD_SET(*this, FIX::LegUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::LegPriceUnitOfMeasure);
+      FIELD_SET(*this, FIX::LegPriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::LegTimeUnit);
+      FIELD_SET(*this, FIX::LegExerciseStyle);
       FIELD_SET(*this, FIX::LegCouponRate);
       FIELD_SET(*this, FIX::LegSecurityExchange);
       FIELD_SET(*this, FIX::LegIssuer);
@@ -292,16 +397,8 @@ namespace FIX50SP1
       FIELD_SET(*this, FIX::LegDatedDate);
       FIELD_SET(*this, FIX::LegContractSettlMonth);
       FIELD_SET(*this, FIX::LegInterestAccrualDate);
-      FIELD_SET(*this, FIX::LegUnitOfMeasure);
-      FIELD_SET(*this, FIX::LegTimeUnit);
-      FIELD_SET(*this, FIX::LegOptionRatio);
-      FIELD_SET(*this, FIX::LegPrice);
-      FIELD_SET(*this, FIX::LegMaturityTime);
       FIELD_SET(*this, FIX::LegPutOrCall);
-      FIELD_SET(*this, FIX::LegExerciseStyle);
-      FIELD_SET(*this, FIX::LegUnitOfMeasureQty);
-      FIELD_SET(*this, FIX::LegPriceUnitOfMeasure);
-      FIELD_SET(*this, FIX::LegPriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::LegOptionRatio);
     };
     FIELD_SET(*this, FIX::Quantity);
     FIELD_SET(*this, FIX::QtyType);
@@ -376,13 +473,22 @@ namespace FIX50SP1
     FIELD_SET(*this, FIX::YieldRedemptionDate);
     FIELD_SET(*this, FIX::YieldRedemptionPrice);
     FIELD_SET(*this, FIX::YieldRedemptionPriceType);
+    FIELD_SET(*this, FIX::NoPosAmt);
+    class NoPosAmt: public FIX::Group
+    {
+    public:
+    NoPosAmt() : FIX::Group(753,707,FIX::message_order(707,708,1055,0)) {}
+      FIELD_SET(*this, FIX::PosAmtType);
+      FIELD_SET(*this, FIX::PosAmt);
+      FIELD_SET(*this, FIX::PositionCurrency);
+    };
     FIELD_SET(*this, FIX::TotNoAllocs);
     FIELD_SET(*this, FIX::LastFragment);
     FIELD_SET(*this, FIX::NoAllocs);
     class NoAllocs: public FIX::Group
     {
     public:
-    NoAllocs() : FIX::Group(78,79,FIX::message_order(79,661,573,366,80,467,81,539,208,209,161,360,361,12,13,479,497,153,154,119,737,120,736,155,156,742,741,136,576,780,172,169,170,171,989,1002,993,992,1047,635,0)) {}
+    NoAllocs() : FIX::Group(78,79,FIX::message_order(79,661,573,366,80,467,81,989,1002,993,1047,992,539,208,209,161,360,361,12,13,479,497,153,154,119,737,120,736,155,156,742,741,136,576,635,780,172,169,170,171,0)) {}
       FIELD_SET(*this, FIX::AllocAccount);
       FIELD_SET(*this, FIX::AllocAcctIDSource);
       FIELD_SET(*this, FIX::MatchStatus);
@@ -390,6 +496,11 @@ namespace FIX50SP1
       FIELD_SET(*this, FIX::AllocQty);
       FIELD_SET(*this, FIX::IndividualAllocID);
       FIELD_SET(*this, FIX::ProcessCode);
+      FIELD_SET(*this, FIX::SecondaryIndividualAllocID);
+      FIELD_SET(*this, FIX::AllocMethod);
+      FIELD_SET(*this, FIX::AllocCustomerCapacity);
+      FIELD_SET(*this, FIX::AllocPositionEffect);
+      FIELD_SET(*this, FIX::IndividualAllocType);
       FIELD_SET(*this, FIX::NoNestedPartyIDs);
       class NoNestedPartyIDs: public FIX::Group
       {
@@ -443,36 +554,37 @@ namespace FIX50SP1
       NoClearingInstructions() : FIX::Group(576,577,FIX::message_order(577,0)) {}
         FIELD_SET(*this, FIX::ClearingInstruction);
       };
+      FIELD_SET(*this, FIX::ClearingFeeIndicator);
       FIELD_SET(*this, FIX::AllocSettlInstType);
       FIELD_SET(*this, FIX::SettlDeliveryType);
       FIELD_SET(*this, FIX::StandInstDbType);
       FIELD_SET(*this, FIX::StandInstDbName);
       FIELD_SET(*this, FIX::StandInstDbID);
-      FIELD_SET(*this, FIX::SecondaryIndividualAllocID);
-      FIELD_SET(*this, FIX::AllocMethod);
-      FIELD_SET(*this, FIX::AllocCustomerCapacity);
-      FIELD_SET(*this, FIX::IndividualAllocType);
-      FIELD_SET(*this, FIX::AllocPositionEffect);
-      FIELD_SET(*this, FIX::ClearingFeeIndicator);
-    };
-    FIELD_SET(*this, FIX::ClearingBusinessDate);
-    FIELD_SET(*this, FIX::TrdType);
-    FIELD_SET(*this, FIX::TrdSubType);
-    FIELD_SET(*this, FIX::MultiLegReportingType);
-    FIELD_SET(*this, FIX::CustOrderCapacity);
-    FIELD_SET(*this, FIX::TradeInputSource);
-    FIELD_SET(*this, FIX::RndPx);
-    FIELD_SET(*this, FIX::MessageEventSource);
-    FIELD_SET(*this, FIX::TradeInputDevice);
-    FIELD_SET(*this, FIX::AvgPxIndicator);
-    FIELD_SET(*this, FIX::NoPosAmt);
-    class NoPosAmt: public FIX::Group
-    {
-    public:
-    NoPosAmt() : FIX::Group(753,707,FIX::message_order(707,708,1055,0)) {}
-      FIELD_SET(*this, FIX::PosAmtType);
-      FIELD_SET(*this, FIX::PosAmt);
-      FIELD_SET(*this, FIX::PositionCurrency);
+      FIELD_SET(*this, FIX::NoDlvyInst);
+      class NoDlvyInst: public FIX::Group
+      {
+      public:
+      NoDlvyInst() : FIX::Group(85,165,FIX::message_order(165,787,781,0)) {}
+        FIELD_SET(*this, FIX::SettlInstSource);
+        FIELD_SET(*this, FIX::DlvyInstType);
+        FIELD_SET(*this, FIX::NoSettlPartyIDs);
+        class NoSettlPartyIDs: public FIX::Group
+        {
+        public:
+        NoSettlPartyIDs() : FIX::Group(781,782,FIX::message_order(782,783,784,801,0)) {}
+          FIELD_SET(*this, FIX::SettlPartyID);
+          FIELD_SET(*this, FIX::SettlPartyIDSource);
+          FIELD_SET(*this, FIX::SettlPartyRole);
+          FIELD_SET(*this, FIX::NoSettlPartySubIDs);
+          class NoSettlPartySubIDs: public FIX::Group
+          {
+          public:
+          NoSettlPartySubIDs() : FIX::Group(801,785,FIX::message_order(785,786,0)) {}
+            FIELD_SET(*this, FIX::SettlPartySubID);
+            FIELD_SET(*this, FIX::SettlPartySubIDType);
+          };
+        };
+      };
     };
   };
 
