@@ -72,6 +72,31 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::StandInstDbType);
       FIELD_SET(*this, FIX::StandInstDbName);
       FIELD_SET(*this, FIX::StandInstDbID);
+      FIELD_SET(*this, FIX::NoDlvyInst);
+      class NoDlvyInst: public FIX::Group
+      {
+      public:
+      NoDlvyInst() : FIX::Group(85,165,FIX::message_order(165,787,781,0)) {}
+        FIELD_SET(*this, FIX::SettlInstSource);
+        FIELD_SET(*this, FIX::DlvyInstType);
+        FIELD_SET(*this, FIX::NoSettlPartyIDs);
+        class NoSettlPartyIDs: public FIX::Group
+        {
+        public:
+        NoSettlPartyIDs() : FIX::Group(781,782,FIX::message_order(782,783,784,801,0)) {}
+          FIELD_SET(*this, FIX::SettlPartyID);
+          FIELD_SET(*this, FIX::SettlPartyIDSource);
+          FIELD_SET(*this, FIX::SettlPartyRole);
+          FIELD_SET(*this, FIX::NoSettlPartySubIDs);
+          class NoSettlPartySubIDs: public FIX::Group
+          {
+          public:
+          NoSettlPartySubIDs() : FIX::Group(801,785,FIX::message_order(785,786,0)) {}
+            FIELD_SET(*this, FIX::SettlPartySubID);
+            FIELD_SET(*this, FIX::SettlPartySubIDType);
+          };
+        };
+      };
       FIELD_SET(*this, FIX::PaymentMethod);
       FIELD_SET(*this, FIX::PaymentRef);
       FIELD_SET(*this, FIX::CardHolderName);
