@@ -52,6 +52,14 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::SymbolSfx);
     FIELD_SET(*this, FIX::SecurityID);
     FIELD_SET(*this, FIX::SecurityIDSource);
+    FIELD_SET(*this, FIX::NoSecurityAltID);
+    class NoSecurityAltID: public FIX::Group
+    {
+    public:
+    NoSecurityAltID() : FIX::Group(454,455,FIX::message_order(455,456,0)) {}
+      FIELD_SET(*this, FIX::SecurityAltID);
+      FIELD_SET(*this, FIX::SecurityAltIDSource);
+    };
     FIELD_SET(*this, FIX::Product);
     FIELD_SET(*this, FIX::ProductComplex);
     FIELD_SET(*this, FIX::SecurityGroup);
@@ -110,12 +118,43 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::SecurityDesc);
     FIELD_SET(*this, FIX::EncodedSecurityDescLen);
     FIELD_SET(*this, FIX::EncodedSecurityDesc);
+    FIELD_SET(*this, FIX::SecurityXMLLen);
+    FIELD_SET(*this, FIX::SecurityXML);
+    FIELD_SET(*this, FIX::SecurityXMLSchema);
     FIELD_SET(*this, FIX::Pool);
     FIELD_SET(*this, FIX::ContractSettlMonth);
     FIELD_SET(*this, FIX::CPProgram);
     FIELD_SET(*this, FIX::CPRegType);
+    FIELD_SET(*this, FIX::NoEvents);
+    class NoEvents: public FIX::Group
+    {
+    public:
+    NoEvents() : FIX::Group(864,865,FIX::message_order(865,866,1145,867,868,0)) {}
+      FIELD_SET(*this, FIX::EventType);
+      FIELD_SET(*this, FIX::EventDate);
+      FIELD_SET(*this, FIX::EventTime);
+      FIELD_SET(*this, FIX::EventPx);
+      FIELD_SET(*this, FIX::EventText);
+    };
     FIELD_SET(*this, FIX::DatedDate);
     FIELD_SET(*this, FIX::InterestAccrualDate);
+    FIELD_SET(*this, FIX::NoInstrumentParties);
+    class NoInstrumentParties: public FIX::Group
+    {
+    public:
+    NoInstrumentParties() : FIX::Group(1018,1019,FIX::message_order(1019,1050,1051,1052,0)) {}
+      FIELD_SET(*this, FIX::InstrumentPartyID);
+      FIELD_SET(*this, FIX::InstrumentPartyIDSource);
+      FIELD_SET(*this, FIX::InstrumentPartyRole);
+      FIELD_SET(*this, FIX::NoInstrumentPartySubIDs);
+      class NoInstrumentPartySubIDs: public FIX::Group
+      {
+      public:
+      NoInstrumentPartySubIDs() : FIX::Group(1052,1053,FIX::message_order(1053,1054,0)) {}
+        FIELD_SET(*this, FIX::InstrumentPartySubID);
+        FIELD_SET(*this, FIX::InstrumentPartySubIDType);
+      };
+    };
     FIELD_SET(*this, FIX::ContractMultiplierUnit);
     FIELD_SET(*this, FIX::FlowScheduleType);
     FIELD_SET(*this, FIX::RestructuringType);
@@ -129,6 +168,35 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::StrikePriceBoundaryPrecision);
     FIELD_SET(*this, FIX::UnderlyingPriceDeterminationMethod);
     FIELD_SET(*this, FIX::OptPayoutType);
+    FIELD_SET(*this, FIX::NoComplexEvents);
+    class NoComplexEvents: public FIX::Group
+    {
+    public:
+    NoComplexEvents() : FIX::Group(1483,1484,FIX::message_order(1484,1485,1486,1487,1488,1489,1490,1491,0)) {}
+      FIELD_SET(*this, FIX::ComplexEventType);
+      FIELD_SET(*this, FIX::ComplexOptPayoutAmount);
+      FIELD_SET(*this, FIX::ComplexEventPrice);
+      FIELD_SET(*this, FIX::ComplexEventPriceBoundaryMethod);
+      FIELD_SET(*this, FIX::ComplexEventPriceBoundaryPrecision);
+      FIELD_SET(*this, FIX::ComplexEventPriceTimeType);
+      FIELD_SET(*this, FIX::ComplexEventCondition);
+      FIELD_SET(*this, FIX::NoComplexEventDates);
+      class NoComplexEventDates: public FIX::Group
+      {
+      public:
+      NoComplexEventDates() : FIX::Group(1491,1492,FIX::message_order(1492,1493,1494,0)) {}
+        FIELD_SET(*this, FIX::ComplexEventStartDate);
+        FIELD_SET(*this, FIX::ComplexEventEndDate);
+        FIELD_SET(*this, FIX::NoComplexEventTimes);
+        class NoComplexEventTimes: public FIX::Group
+        {
+        public:
+        NoComplexEventTimes() : FIX::Group(1494,1495,FIX::message_order(1495,1496,0)) {}
+          FIELD_SET(*this, FIX::ComplexEventStartTime);
+          FIELD_SET(*this, FIX::ComplexEventEndTime);
+        };
+      };
+    };
   };
 
 }
