@@ -3,4 +3,4 @@ require 'test/DataDictionaryTestCase'
 require 'test/DictionaryTestCase'
 require 'test/FieldBaseTestCase'
 require 'test/SessionSettingsTestCase'
-#require 'test/MessageTestCase'
\ No newline at end of file
+require 'test/MessageTestCase'
\ No newline at end of file
