@@ -17,9 +17,6 @@
 
 // TODO: reference additional headers your program requires here
 
-#import <msxml3.dll> raw_interfaces_only
-using namespace MSXML2;
-
 //{{AFX_INSERT_LOCATION}}
 // Microsoft Visual C++ will insert additional declarations immediately before the previous line.
 
